(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     35977,        913]
NotebookOptionsPosition[     32748,        869]
NotebookOutlinePosition[     33092,        884]
CellTagsIndexPosition[     33049,        881]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Using data from the Italian Department of Health, we begin by creating a \
plot of the cumulative number of identified positive cases of COVID-19 in \
Italy.  In our time line, t=0 corresponds to February 21, 2020, so that t=61 \
is April 22.  This plot will be compared with the predicted values from our \
model in each of the time periods February 21, 2020 to March 10, 2020, March \
10 to March 20, and March 20 to April 22.   ",
 StyleBox["Execute the command below by putting the cursor anywhere in the \
line and hitting \[OpenCurlyDoubleQuote]enter\[CloseCurlyDoubleQuote] (i.e., \
\[OpenCurlyDoubleQuote]shift-return\[CloseCurlyDoubleQuote] or just \
\[OpenCurlyDoubleQuote]enter\[CloseCurlyDoubleQuote] on a numeric keypad)",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.797687804096763*^9, 3.7976878783290195`*^9}, {
  3.7976879239687395`*^9, 3.797687957824246*^9}, {3.797687997800226*^9, 
  3.7976880009364204`*^9}, {3.79768812382366*^9, 3.7976882167521515`*^9}, {
  3.7983801710421724`*^9, 3.79838018574201*^9}, {3.8013081715214424`*^9, 
  3.8013082013338137`*^9}},ExpressionUUID->"fcd32ff3-e918-4c90-b04d-\
a83aa8abd546"],

Cell[BoxData[
 RowBox[{"lp1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "712"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "955"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "1128"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "1694"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "1984"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"11", ",", "2423"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"12", ",", "3089"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"13", ",", "3858"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"14", ",", "4636"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"15", ",", "5883"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"16", ",", "7375"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"17", ",", "9172"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"18", ",", "10149"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"19", ",", "12462"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"20", ",", "15113"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"21", ",", "17660"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"22", ",", "21157"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"23", ",", "24747"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"24", ",", "27908"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"25", ",", "31506"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"26", ",", "35713"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"27", ",", "41035"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"28", ",", "47021"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"29", ",", "53578"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"30", ",", "59138"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"31", ",", "63927"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"32", ",", "69176"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"33", ",", "74386"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"34", ",", "80539"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"35", ",", "86498"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"36", ",", "92472"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"37", ",", "97689"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"38", ",", "101739"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"39", ",", "105792"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"40", ",", "110574"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"41", ",", "115242"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"42", ",", "119827"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"43", ",", "124632"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"44", ",", "128948"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"45", ",", "132547"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"46", ",", "135586"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"47", ",", "139422"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"48", ",", "143626"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"49", ",", "147577"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"50", ",", "152271"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"51", ",", "156363"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"52", ",", "159516"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"53", ",", "162488"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"54", ",", "165155"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"55", ",", "168941"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"56", ",", "172434"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"57", ",", "175925"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"58", ",", "178972"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"59", ",", "181228"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"60", ",", "183957"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"61", ",", "187327"}], "}"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", " ", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7976874110429125`*^9, 3.797687733466434*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"64e590ef-8baa-464e-af26-0c9f79e09b3a"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.809265062247098*^9, 
  3.809265062262664*^9}},ExpressionUUID->"b2a08e18-f276-444d-a7a4-\
e3eb6596237e"],

Cell[TextData[{
 "In parts (e) - (g) of  the project you will compute values for the \
parameter \[Beta] to best fit the data in each of the three time periods.  In \
preparation for this, we separate the data for cumulative cases into these \
three periods; ",
 StyleBox["execute each of the next three commands (no output will be \
printed)",
  FontColor->RGBColor[1, 0, 0]],
 ".\n  \n  "
}], "Text",
 CellChangeTimes->{{3.8011486754510217`*^9, 3.801148859863558*^9}, {
  3.801148896383472*^9, 3.801148969342349*^9}, {3.8012155604960117`*^9, 
  3.8012155621910343`*^9}, {3.8013082310165243`*^9, 3.801308283407133*^9}, {
  3.8033850259955597`*^9, 3.80338502945858*^9}, {3.809264581483224*^9, 
  3.8092645853928175`*^9}},ExpressionUUID->"f0fc9f35-948b-44cb-b54c-\
9c9a240d7cab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "712"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "955"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "1128"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "1694"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "1984"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "2423"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "3089"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"13", ",", "3858"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "4636"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"15", ",", "5883"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"16", ",", "7375"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "9172"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "10149"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80114898174319*^9, 3.801148995102478*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"6b38a2c3-41bd-47ee-add2-58ec0a09680c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"18", ",", "10149"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"19", ",", "12462"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "15113"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21", ",", "17660"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"22", ",", "21157"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", "24747"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"24", ",", "27908"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"25", ",", "31506"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"26", ",", "35713"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", "41035"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"28", ",", "47021"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.801149034618664*^9, 3.80114905451018*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"cfdb380d-e175-4386-bd74-49995a5d124c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"28", ",", "47021"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"29", ",", "53578"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30", ",", "59138"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"31", ",", "63927"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"32", ",", "69176"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"33", ",", "74386"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"34", ",", "80539"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "86498"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"36", ",", "92472"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"37", ",", "97689"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"38", ",", "101739"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"39", ",", "105792"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"40", ",", "110574"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"41", ",", "115242"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"42", ",", "119827"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"43", ",", "124632"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"44", ",", "128948"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"45", ",", "132547"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"46", ",", "135586"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"47", ",", "139422"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"48", ",", "143626"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"49", ",", "147577"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"50", ",", "152271"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"51", ",", "156363"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"52", ",", "159516"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"53", ",", "162488"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"54", ",", "165155"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"55", ",", "168941"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"56", ",", "172434"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"57", ",", "175925"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"58", ",", "178972"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"59", ",", "181228"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "183957"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"61", ",", "187327"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8011490917676687`*^9, 3.801149104118539*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"d6c7b47b-8022-4e6c-8a8b-9dcae0dab1ae"],

Cell[TextData[{
 "In part (e) we want to best fit the data in data1 to a function of the form \
A( Exp[Bt]-1)/B.  This will tell us ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", 
    RowBox[{"1", " "}]], TraditionalForm]],ExpressionUUID->
  "daf1354f-b320-4152-8160-cff06e2c814a"],
 "(=B) and \[Eta] I(0) (=A).  Since we know \[Eta]=0.0333, this allows us to \
determine our \[OpenCurlyDoubleQuote]best fit\[CloseCurlyDoubleQuote] value \
of I(0).  The relevant command is as follows; ",
 StyleBox["execute this command to find A and B, and then determine ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", 
    RowBox[{"1", " "}]], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "6812df70-bba0-4483-8fc8-0d4c63d130da"],
 StyleBox[" and  I(0).",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.8011492524309173`*^9, 3.8011494729885807`*^9}, {
  3.801149543891647*^9, 3.801149553509107*^9}, {3.8012156007347813`*^9, 
  3.8012156587033153`*^9}, {3.8091797381686525`*^9, 
  3.809179753417347*^9}},ExpressionUUID->"1c709076-0187-4542-a420-\
b92eae1d54c8"],

Cell["\<\

\
\>", "Text",
 CellChangeTimes->{
  3.8011492360294*^9, {3.809181820615326*^9, 
   3.8091820269760528`*^9}},ExpressionUUID->"bc3098c6-b0d9-4c57-8432-\
a448c6af2320"],

Cell[BoxData[
 RowBox[{"FindFit", "[", 
  RowBox[{"data1", ",", 
   RowBox[{"A", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"B", "*", "t"}], "]"}], "-", "1"}], ")"}], "/", "B"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"A", ",", "B"}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{3.8011492293012695`*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"92709bc8-4aa6-413b-8ecb-ab9bd563376e"],

Cell[BoxData[""], "Text", "Input",
 CellChangeTimes->{{3.8091820303229065`*^9, 3.8091821420218873`*^9}, {
   3.8091821977407427`*^9, 3.809182206833843*^9}, {3.8091824186346207`*^9, 
   3.809182420367614*^9}, 
   3.8092646993680463`*^9},ExpressionUUID->"20fa8bee-726e-41c0-a13e-\
a87fc4e615ae"],

Cell[TextData[{
 "Part (f): Using the just determined values of I(0) and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "1"], TraditionalForm]],ExpressionUUID->
  "259a0a1e-31cd-4953-9dbd-980ce5076149"],
 "from part (e) we want to best fit the data in data2 to a function of the \
form 68.20(Exp[(18)(.1898)]-1)/.1898+68.20Exp[(.1898)(18)](Exp[D(t-18)])/D-68.\
2Exp[(.1898)(18)]/D; t",
 StyleBox["he numbers in this expression come from the values of I(0), ",
  FontColor->GrayLevel[0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Rho]", "1"], ",", " "}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "d15febed-1ebc-47bd-a41e-71542c29f079"],
 StyleBox[" and \[Eta].  ",
  FontColor->GrayLevel[0]],
 StyleBox["Copy the \[OpenCurlyDoubleQuote]FindFit\[CloseCurlyDoubleQuote] \
command above, and then modify it to determine D and hence ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "2"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "dbaee4e7-3d7e-4adb-881a-8e4f1eb5791f"],
 StyleBox[" and ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "2"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "99757a13-7302-49aa-af0a-d295c34fbb2d"],
 " ",
 StyleBox["for the second time period.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.8011495880351696`*^9, 3.801149592267717*^9}, {
  3.8011496315630293`*^9, 3.801149698627325*^9}, {3.801150027105672*^9, 
  3.80115013266473*^9}, {3.801150167312727*^9, 3.801150171953046*^9}, {
  3.8012157149898186`*^9, 3.801215808621764*^9}, {3.803385037154127*^9, 
  3.8033850374829383`*^9}, {3.809182260662468*^9, 3.809182280338765*^9}, {
  3.8093599378409767`*^9, 
  3.8093600903699107`*^9}},ExpressionUUID->"4ab93f48-a34c-40ab-8e1e-\
02d756f5f5d2"],

Cell["", "Text",
 CellChangeTimes->{{3.8011490221608677`*^9, 
  3.8011490304460735`*^9}},ExpressionUUID->"4aa86e6b-a506-4562-94dc-\
46690a92fd16"],

Cell[TextData[{
 "Part (g):  We want to best fit the data in data3 to a function of the form  \
68.2(Exp[(.1898)(18)]-1)/.1898+68.2Exp[(.1898)(18)](Exp[(.1018)(28-18)]-1)/.\
1018 +68.2Exp[(.1898)(18)]Exp[ (.1018)(28-18)](Exp[c(t-28)]-1)/c  .  ",
 StyleBox["Use the FindFit command to determine c and then compute ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "3"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "4a1135a0-6efc-4692-9dbe-8f65953b99f2"],
 StyleBox[" and ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "3"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "c6b07d1f-4a12-4925-bbac-b7c5ec6bc12f"],
 StyleBox[".",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.797688452991123*^9, 3.7976887855256443`*^9}, {
   3.7976888255495977`*^9, 3.79768894325382*^9}, {3.7983801980891705`*^9, 
   3.798380198870369*^9}, {3.8011491394711304`*^9, 3.80114921924609*^9}, {
   3.801149500796526*^9, 3.8011495582283673`*^9}, {3.8011500136904163`*^9, 
   3.801150015898141*^9}, {3.801150208855792*^9, 3.8011502324890976`*^9}, 
   3.801150356514494*^9, {3.8012158297335753`*^9, 3.801215927796959*^9}, {
   3.8013087815337763`*^9, 3.801308903454561*^9}, {3.8033850422741776`*^9, 
   3.8033850483546734`*^9}, {3.8092638519708247`*^9, 
   3.8092638525772977`*^9}},ExpressionUUID->"c4b9aad3-3a04-4dfa-bedb-\
f1930c9c1fa0"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.809439188904222*^9},ExpressionUUID->"ad250d4b-2be1-4ac0-9ced-\
57886f574c76"],

Cell[TextData[{
 "\n\n",
 StyleBox["Part (h), first time period:",
  FontWeight->"Bold"],
 "  Next we illustrate using the NDSolve (numerical differential equation \
solve) command for our SIQR model during the time period February 21, 2020 \
(t=0) to March 10 (t=18) with the parameter values as discussed for this \
period.  We will write s[t], i[t], q[t], and r[t] for, respectively, S(t), \
I(t), Q(t) and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "Q"], TraditionalForm]],ExpressionUUID->
  "ae45875b-62cc-4ef0-9d63-cd2b52007d40"],
 "(t) (the reason we change to lower cases letters is because capital I has a \
protected meaning (the imaginary constant) in Mathematica.  We are not so \
interested in the other removed compartment, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "I"], TraditionalForm]],ExpressionUUID->
  "133ccb49-b02f-4a10-aea6-ce6a07a4f594"],
 "(t) (keep in mind that this compartment is invisible to us when we compare \
with actual data at our disposal), and since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "I"], TraditionalForm]],ExpressionUUID->
  "864b6df0-b860-4ac9-8179-56e6ee0e38c2"],
 " does not appear in any other equation in our system we can just omit the \
fifth equation from our model with no ill effects.  The initial conditions \
represent the approximate population of Italy (N=60,360,000) essentially all \
susceptible, and an initial infectious population of 2048, none of whom who \
have yet been identified as COVID-19 positive. ",
 StyleBox[" Execute the next two commands to numerically solve our system and \
then plot the graph of q[t]+r[t] for the first time period; as discussed in \
the project, q[t]+r[t] is the cumulative number of identified cases at time \
t.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.797688452991123*^9, 3.7976887855256443`*^9}, {
  3.7976888255495977`*^9, 3.79768894325382*^9}, {3.7983801980891705`*^9, 
  3.798380198870369*^9}, {3.8011491394711304`*^9, 3.80114921924609*^9}, {
  3.801149500796526*^9, 3.8011495582283673`*^9}, {3.8011500136904163`*^9, 
  3.801150015898141*^9}, {3.801150208855792*^9, 3.8011502324890976`*^9}, {
  3.801216111388966*^9, 3.8012162261567073`*^9}, {3.8012163552441797`*^9, 
  3.801216406939336*^9}, {3.8013089817975674`*^9, 3.8013089877983217`*^9}, {
  3.8013100807334204`*^9, 3.8013100955186133`*^9}, {3.8033850559462986`*^9, 
  3.803385056308089*^9}, {3.809263862026976*^9, 
  3.8092638854563255`*^9}},ExpressionUUID->"1b9d62b7-4421-40d7-9e80-\
795d36be6ad4"],

Cell[BoxData[
 RowBox[{"solution1", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["s", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", ".2898"}], "/", "60360000"}], 
        RowBox[{"s", "[", "t", "]"}], "*", 
        RowBox[{"i", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"q", "'"}], "[", "t", "]"}], "==", 
       RowBox[{
        RowBox[{".033", "*", 
         RowBox[{"i", "[", "t", "]"}]}], "-", 
        RowBox[{".041", "*", 
         RowBox[{"q", "[", "t", "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["i", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{".2898", "/", "60360000"}], 
         RowBox[{"s", "[", "t", "]"}], "*", 
         RowBox[{"i", "[", "t", "]"}]}], "-", 
        RowBox[{".1", "*", 
         RowBox[{"i", "[", "t", "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "'"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{".041", "*", 
        RowBox[{"q", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"s", "[", "0", "]"}], "\[Equal]", "60360000"}], ",", 
      RowBox[{
       RowBox[{"i", "[", "0", "]"}], "\[Equal]", "2048"}], ",", 
      RowBox[{
       RowBox[{"q", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "i", ",", "q", ",", "r"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8011583166794558`*^9, 3.801158361038844*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"29c66247-1f2b-4406-a8d9-c557c2b3833a"],

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"q", "[", "t", "]"}], "+", 
        RowBox[{"r", "[", "t", "]"}]}], "}"}], "/.", "solution1"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "18"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Red", "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", "\"\<q(t)+r(t),0\[LessEqual]t\[LessEqual]18\>\"", "}"}]}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.801158385502721*^9, 3.8011583890466747`*^9}, {
  3.8012164838909097`*^9, 3.8012164927517924`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"e8cac65f-de23-4660-bae9-b4387ef0a1db"],

Cell[TextData[{
 "We can compare this with the actual data for cumulative cases (given in \
lp1) using the Show command.  Remark: ",
 StyleBox[" The commands Show[p1,lp1] and Show[lp1,p1] give somewhat \
different outputs; execute both of the following commands to see the \
difference.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.801216523238193*^9, 3.80121657461753*^9}, {
  3.8012166941615133`*^9, 3.8012167421847878`*^9}, {3.8013090400925393`*^9, 
  3.8013090464706483`*^9}, {3.801310110904463*^9, 3.8013101199698067`*^9}, {
  3.809360148116194*^9, 
  3.8093601757034144`*^9}},ExpressionUUID->"9c88a540-67f3-484c-a59b-\
cdc299143ea2"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8012165317872562`*^9, 
  3.8012165359618454`*^9}},ExpressionUUID->"34664ffb-ed8b-483d-b200-\
ce66d02dc771"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "lp1"}], "]"}]], "Input",
 CellChangeTimes->{{3.801158426616042*^9, 3.8011584368941097`*^9}, {
  3.801216589914715*^9, 3.8012165939453707`*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"39065c02-c76e-4fe9-9ac7-2b7f8aa9829d"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"lp1", ",", "p1"}], "]"}]], "Input",
 CellChangeTimes->{{3.801216756786368*^9, 3.801216761217799*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"4e2615f2-d9cf-468f-b21c-95c5bb236e53"],

Cell[TextData[{
 "For the second time period we will need the values of I, Q, and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "Q"], TraditionalForm]],ExpressionUUID->
  "8d9c5325-8001-4fd5-8fe0-c0c982003489"],
 " at t=18.  ",
 StyleBox["Execute the next line to compute these:",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.801216794752446*^9, 3.8012168979608526`*^9}, {
  3.8033850655297747`*^9, 3.803385065892563*^9}, {3.809263917425922*^9, 
  3.8092639247140718`*^9}},ExpressionUUID->"603ed869-c087-4130-91af-\
f03f47801ee2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"i", "[", "18", "]"}], "/.", "solution1"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"q", "[", "18", "]"}], "/.", "solution1"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"r", "[", "18", "]"}], "/.", "solution1"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"s", "[", "18", "]"}], "/.", "solution1"}], "]"}], "}"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.801158631798584*^9, 3.80115865389283*^9}, {
  3.8012170944394207`*^9, 3.801217099400557*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"ec300f47-8d87-45cb-8ed3-9c7c7d316ca8"],

Cell[TextData[{
 StyleBox["Part (h), second time period:",
  FontWeight->"Bold"],
 "  ",
 StyleBox["Numerically solve the system of differential equations for the \
second time period by modifying the \[OpenCurlyDoubleQuote]solution1\
\[CloseCurlyDoubleQuote] command, using the values of ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "2"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "301352b2-3a33-4f5e-8d63-199af30f136e"],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"and", " ", 
     SubscriptBox["\[Beta]", "2"]}]}], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "cbfe6455-2fa3-451f-b0ae-dd95982778f7"],
 StyleBox[", and the just computed values of i, q, r, and s at t=18 as the \
initial conditions.  Then plot the graph of your solution for q+r in blue \
during the second time period.  Show this graph together with the actual data \
points.  Finally, for use in the third time period, compute i, q, r, and s at \
t=28.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.8012169115759954`*^9, 3.801217072407142*^9}, {
  3.8012171628229413`*^9, 3.8012173018067017`*^9}, {3.801217351717888*^9, 
  3.801217371886259*^9}, {3.8013091018835697`*^9, 3.801309102770895*^9}, {
  3.803385070410959*^9, 3.8033850707307763`*^9}, {3.809263934320981*^9, 
  3.8092639625802507`*^9}},ExpressionUUID->"7200c2be-0abf-468b-a81f-\
9e8f82db09c8"],

Cell[BoxData[
 RowBox[{"solution2", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["s", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", ".2018"}], "/", "60360000"}], 
        RowBox[{"s", "[", "t", "]"}], "*", 
        RowBox[{"i", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"q", "'"}], "[", "t", "]"}], "==", 
       RowBox[{
        RowBox[{".033", "*", 
         RowBox[{"i", "[", "t", "]"}]}], "-", 
        RowBox[{".038", "*", 
         RowBox[{"q", "[", "t", "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["i", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{".2018", "/", "60360000"}], 
         RowBox[{"s", "[", "t", "]"}], "*", 
         RowBox[{"i", "[", "t", "]"}]}], "-", 
        RowBox[{".1", "*", 
         RowBox[{"i", "[", "t", "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "'"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{".038", "*", 
        RowBox[{"q", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"s", "[", "18", "]"}], "\[Equal]", "60268000"}], ",", 
      RowBox[{
       RowBox[{"i", "[", "18", "]"}], "\[Equal]", "62253"}], ",", 
      RowBox[{
       RowBox[{"q", "[", "18", "]"}], "\[Equal]", "8770"}], ",", 
      RowBox[{
       RowBox[{"r", "[", "18", "]"}], "\[Equal]", "1710"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "i", ",", "q", ",", "r"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "18", ",", "100"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.801158474478411*^9, 3.8011584981357503`*^9}, {
  3.801158666941311*^9, 3.8011586935659237`*^9}, {3.8012171077927103`*^9, 
  3.8012171200086594`*^9}, {3.8092639809582443`*^9, 3.809263982368269*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"d79e888b-6cc6-46cc-aa1b-4edaf6af0c32"],

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"q", "[", "t", "]"}], "+", 
        RowBox[{"r", "[", "t", "]"}]}], "}"}], "/.", "solution2"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "18", ",", "28"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Blue", "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{
     "{", "\"\<q(t)+r(t),18\[LessEqual]t\[LessEqual]28\>\"", "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.801158742124905*^9, 3.8011587574540396`*^9}, {
  3.8011588113419266`*^9, 3.8011588170926085`*^9}, {3.8013092489229317`*^9, 
  3.8013092561138043`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"c09ad96a-2099-4f75-bbcc-f2b29585441b"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p2", ",", "lp1"}], "]"}]], "Input",
 CellChangeTimes->{{3.801158786540249*^9, 3.8011587876925983`*^9}, {
  3.801309315520914*^9, 3.801309326568511*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"1e880e07-bab9-4eb0-b151-153c41a50bd2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"i", "[", "28", "]"}], "/.", "solution2"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"q", "[", "28", "]"}], "/.", "solution2"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"r", "[", "28", "]"}], "/.", "solution2"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"s", "[", "28", "]"}], "/.", "solution2"}], "]"}], "}"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.8011588315882387`*^9, 3.8011588475160446`*^9}, {
  3.801158983900321*^9, 3.8011590149653683`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"f088c216-df58-4a85-99f8-8b92c1c9f691"],

Cell[TextData[{
 StyleBox["Part (h), third time period:",
  FontWeight->"Bold"],
 "  ",
 StyleBox["Numerically solve the system of differential equations for the \
third time period by modifying the \[OpenCurlyDoubleQuote]solution1\
\[CloseCurlyDoubleQuote] command, using the values of ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "3"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "e82d204f-9c88-4a11-8704-4636d608b327"],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"and", " ", 
     SubscriptBox["\[Beta]", "3"]}]}], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "979e07d4-4e48-4ac4-9ff9-5f4dde5c80ab"],
 StyleBox[", and the just computed values of i, q, r, and s at t=28 as the \
initial conditions.  Then plot the graph of your solution for q+r in green \
during the third time period.  Show this graph together with the actual data \
points.  ",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.801217393527751*^9, 3.801217432838053*^9}, {
  3.8033850801543427`*^9, 3.803385080498145*^9}, {3.809264123258029*^9, 
  3.8092641311253223`*^9}},ExpressionUUID->"89738601-50b4-457c-8d42-\
0cb0352a5f64"],

Cell[BoxData[""], "Text",
 CellChangeTimes->{
  3.801309374818469*^9, {3.801309405736045*^9, 3.8013094355844016`*^9}, {
   3.809264496568797*^9, 
   3.8092644998224125`*^9}},ExpressionUUID->"62aa0968-c8c5-4ddf-b2fb-\
d71e1da1bcb5"],

Cell[TextData[StyleBox["Finally, use the Show command to  show the graphs of \
the solutions for q+r for 0\[LessEqual]t\[LessEqual]61 together with all of \
the data points.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.8013094428645167`*^9, 
  3.8013095482533107`*^9}},ExpressionUUID->"ed8c0581-d9d9-4de4-85b8-\
62946c614341"]
},
WindowSize->{759, 833},
WindowMargins->{{Automatic, 427}, {-33, Automatic}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1174, 18, 144, "Text",ExpressionUUID->"fcd32ff3-e918-4c90-b04d-a83aa8abd546"],
Cell[1735, 40, 4365, 123, 200, "Input",ExpressionUUID->"64e590ef-8baa-464e-af26-0c9f79e09b3a"],
Cell[6103, 165, 152, 3, 28, "Input",ExpressionUUID->"b2a08e18-f276-444d-a7a4-e3eb6596237e"],
Cell[6258, 170, 778, 15, 122, "Text",ExpressionUUID->"f0fc9f35-948b-44cb-b54c-9c9a240d7cab"],
Cell[7039, 187, 1109, 32, 48, "Input",ExpressionUUID->"6b38a2c3-41bd-47ee-add2-58ec0a09680c"],
Cell[8151, 221, 991, 28, 48, "Input",ExpressionUUID->"cfdb380d-e175-4386-bd74-49995a5d124c"],
Cell[9145, 251, 2582, 74, 124, "Input",ExpressionUUID->"d6c7b47b-8022-4e6c-8a8b-9dcae0dab1ae"],
Cell[11730, 327, 1137, 26, 78, "Text",ExpressionUUID->"1c709076-0187-4542-a420-b92eae1d54c8"],
Cell[12870, 355, 177, 7, 56, "Text",ExpressionUUID->"bc3098c6-b0d9-4c57-8432-a448c6af2320"],
Cell[13050, 364, 444, 12, 28, "Input",ExpressionUUID->"92709bc8-4aa6-413b-8ecb-ab9bd563376e"],
Cell[13497, 378, 293, 5, 28, "Text",ExpressionUUID->"20fa8bee-726e-41c0-a13e-a87fc4e615ae"],
Cell[13793, 385, 1871, 45, 122, "Text",ExpressionUUID->"4ab93f48-a34c-40ab-8e1e-02d756f5f5d2"],
Cell[15667, 432, 146, 3, 34, "Text",ExpressionUUID->"4aa86e6b-a506-4562-94dc-46690a92fd16"],
Cell[15816, 437, 1457, 30, 100, "Text",ExpressionUUID->"c4b9aad3-3a04-4dfa-bedb-f1930c9c1fa0"],
Cell[17276, 469, 147, 3, 48, "Input",ExpressionUUID->"ad250d4b-2be1-4ac0-9ced-57886f574c76"],
Cell[17426, 474, 2513, 47, 322, "Text",ExpressionUUID->"1b9d62b7-4421-40d7-9e80-795d36be6ad4"],
Cell[19942, 523, 1883, 52, 86, "Input",ExpressionUUID->"29c66247-1f2b-4406-a8d9-c557c2b3833a"],
Cell[21828, 577, 770, 20, 48, "Input",ExpressionUUID->"e8cac65f-de23-4660-bae9-b4387ef0a1db"],
Cell[22601, 599, 662, 13, 78, "Text",ExpressionUUID->"9c88a540-67f3-484c-a59b-cdc299143ea2"],
Cell[23266, 614, 156, 3, 28, "Input",ExpressionUUID->"34664ffb-ed8b-483d-b200-ce66d02dc771"],
Cell[23425, 619, 281, 5, 28, "Input",ExpressionUUID->"39065c02-c76e-4fe9-9ac7-2b7f8aa9829d"],
Cell[23709, 626, 228, 4, 28, "Input",ExpressionUUID->"4e2615f2-d9cf-468f-b21c-95c5bb236e53"],
Cell[23940, 632, 555, 13, 58, "Text",ExpressionUUID->"603ed869-c087-4130-91af-f03f47801ee2"],
Cell[24498, 647, 805, 22, 48, "Input",ExpressionUUID->"ec300f47-8d87-45cb-8ed3-9c7c7d316ca8"],
Cell[25306, 671, 1501, 34, 122, "Text",ExpressionUUID->"7200c2be-0abf-468b-a81f-9e8f82db09c8"],
Cell[26810, 707, 2046, 54, 86, "Input",ExpressionUUID->"d79e888b-6cc6-46cc-aa1b-4edaf6af0c32"],
Cell[28859, 763, 934, 25, 48, "Input",ExpressionUUID->"c09ad96a-2099-4f75-bbcc-f2b29585441b"],
Cell[29796, 790, 278, 5, 28, "Input",ExpressionUUID->"1e880e07-bab9-4eb0-b151-153c41a50bd2"],
Cell[30077, 797, 810, 22, 48, "Input",ExpressionUUID->"f088c216-df58-4a85-99f8-8b92c1c9f691"],
Cell[30890, 821, 1271, 31, 100, "Text",ExpressionUUID->"89738601-50b4-457c-8d42-0cb0352a5f64"],
Cell[32164, 854, 231, 5, 33, "Text",ExpressionUUID->"62aa0968-c8c5-4ddf-b2fb-d71e1da1bcb5"],
Cell[32398, 861, 346, 6, 56, "Text",ExpressionUUID->"ed8c0581-d9d9-4de4-85b8-62946c614341"]
}
]
*)

