(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    294081,       6040]
NotebookOptionsPosition[    286077,       5922]
NotebookOutlinePosition[    286569,       5942]
CellTagsIndexPosition[    286526,       5939]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["NO VACCINE MODEL:",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.818435223680667*^9, 
  3.8184352321361465`*^9}},ExpressionUUID->"a436f254-6b92-4a9e-b252-\
6eae1621cf32"],

Cell[TextData[{
 "Part (g):  We first illustrate how to solve the no-vaccine  model with the  \
rate parameter values given in Table 1 and using the value of \[Beta] \
corresponding to a reproductive number ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],ExpressionUUID->
  "b177d226-4198-430f-996e-401ad583b63d"],
 "=1.8.",
 StyleBox["  Execute the next line by putting your cursor anywhere in the \
line and hitting \[OpenCurlyDoubleQuote]shift\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]enter\[CloseCurlyDoubleQuote] simultaneously.",
  FontColor->RGBColor[1, 0, 0]],
 "  The semicolon at the end of the command suppresses the output, but we \
will be able to use the numerical solutions produced to answer the other \
questions in (g)."
}], "Text",
 CellChangeTimes->{{3.8173926005709143`*^9, 3.8173927551802244`*^9}, {
  3.8179130157534122`*^9, 3.8179130438939915`*^9}, {3.8179131018320184`*^9, 
  3.8179131174127703`*^9}, {3.8179131618340845`*^9, 3.817913263881338*^9}, {
  3.8179148550626125`*^9, 3.817914856744607*^9}, {3.8180820093312006`*^9, 
  3.818082013755402*^9}, {3.8184345166880474`*^9, 3.8184345198642206`*^9}, {
  3.8197230968058095`*^9, 
  3.8197230985558467`*^9}},ExpressionUUID->"7a570a02-82fb-478f-a7ec-\
41eb3cabe267"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sample1", "=", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"-", " ", ".33"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", "[", "t", "]"}], "+", 
            RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
          RowBox[{
           RowBox[{"u", "[", "t", "]"}], "/", "100000"}]}]}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["e", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
         RowBox[{
          RowBox[{".33", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", "[", "t", "]"}], "+", 
             RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], "/", "100000"}]}], "-", 
          RowBox[{".333", 
           RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".555"}], 
           RowBox[{"a", "[", "t", "]"}]}], "+", 
          RowBox[{".333", 
           RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".1667"}], 
           RowBox[{"m", "[", "t", "]"}]}], "+", 
          RowBox[{".333", 
           RowBox[{"a", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"s", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".25"}], 
           RowBox[{"s", "[", "t", "]"}]}], "+", 
          RowBox[{".0833", 
           RowBox[{"m", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".0714"}], 
           RowBox[{"c", "[", "t", "]"}]}], "+", 
          RowBox[{".05", 
           RowBox[{"s", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{".0107", 
           RowBox[{"c", "[", "t", "]"}]}], "+", 
          RowBox[{".00167", 
           RowBox[{"m", "[", "t", "]"}]}], "+", 
          RowBox[{".025", 
           RowBox[{"s", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"r", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{".222", 
           RowBox[{"a", "[", "t", "]"}]}], "+", 
          RowBox[{".0817", 
           RowBox[{"m", "[", "t", "]"}]}], "+", 
          RowBox[{".175", 
           RowBox[{"s", "[", "t", "]"}]}], "+", 
          RowBox[{".0607", 
           RowBox[{"c", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{"u", "[", "0", "]"}], "\[Equal]", "90900"}], ",", 
        RowBox[{
         RowBox[{"e", "[", "0", "]"}], "\[Equal]", "100"}], ",", 
        RowBox[{
         RowBox[{"a", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"m", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"s", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"c", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"d", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"r", "[", "0", "]"}], "\[Equal]", "9000"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "u", ",", "e", ",", "a", ",", "m", ",", "s", ",", "c", ",", "d", ",", 
        "r"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "180"}], "}"}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.8173922364911814`*^9, 3.817392248115712*^9}, {
   3.817392292380958*^9, 3.8173923308838186`*^9}, {3.8173928013973703`*^9, 
   3.8173928365222054`*^9}, {3.817392933318962*^9, 3.8173929760228195`*^9}, {
   3.8173930070852633`*^9, 3.8173930077259703`*^9}, 3.8179131835382395`*^9, {
   3.818252353304367*^9, 3.818252372245778*^9}, {3.8182524174647646`*^9, 
   3.818252435502785*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"529fa9d4-be55-48b6-ae77-78151d4ecad7"],

Cell[TextData[StyleBox["Execute the next command to see the requested graphs \
of e(t),a(t), m(t), s(t), c(t) and d(t).  ",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.817913348289734*^9, 3.817913410937563*^9}, {
  3.817913573640115*^9, 3.817913612754692*^9}, {3.817913827669299*^9, 
  3.8179138732246857`*^9}, {3.81843461772821*^9, 
  3.8184346543192153`*^9}},ExpressionUUID->"ba05c20c-bd69-4c93-8303-\
4384f7a8d1c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"e", "[", "t", "]"}], ",", 
       RowBox[{"a", "[", "t", "]"}], ",", 
       RowBox[{"m", "[", "t", "]"}], ",", 
       RowBox[{"s", "[", "t", "]"}], ",", 
       RowBox[{"c", "[", "t", "]"}], ",", 
       RowBox[{"d", "[", "t", "]"}]}], "}"}], "/.", "sample1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "180"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Darker", "[", "Yellow", "]"}], ",", "Green", ",", " ", 
      "Yellow", ",", "Red", ",", "Black"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "180"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "3500"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<e(t)\>\"", ",", "\"\<a(t)\>\"", ",", "\"\<m(t)\>\"", ",", 
      "\"\<s(t)\>\"", ",", "\"\<c(t)\>\"", ",", "\"\<d(t)\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.8173923769451485`*^9},
 CellLabel->"In[2]:=",ExpressionUUID->"fdeb75a8-38df-49a0-99cf-c277013b3c7d"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwVl3c81f8Xx5VCRLJHCaGIBrLHK6txr3W599rj3uvaI2SvhpZSSZFS4l4h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          "]]}, Annotation[#, "Charting`Private`Tag$2931#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwVl3c8lY8Xx4VKVnZWMhrIKHvE/ZgRGeFeM+NeF2WvfLOFoqhk3FtpkZVU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          "]]}, Annotation[#, "Charting`Private`Tag$2931#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 0]], 
         LineBox[CompressedData["
1:eJwVlnk4Vd8XxsmQZFYyJWOFqEwRua9ZpiTce83c64pkTpQhyljG9G1QSLgn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          "]]}, Annotation[#, "Charting`Private`Tag$2931#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 1, 0]], 
         LineBox[CompressedData["
1:eJwV13k8VN0fB3DKHsrSYqksrRJFtiz3Y1+zGzNDyIxB2ZMHESUUgyHZilJS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          "]]}, Annotation[#, "Charting`Private`Tag$2931#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwt1nc8lt//B3CVnabshqxCkZFROC8jm+xx37fNHbJCsrLuO0olMkpoiIZQ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          "]]}, Annotation[#, "Charting`Private`Tag$2931#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwV12c4Fe4fBnDqR1YZZZTKVmSFjIznxsle2SIOjmNkNISkqEhFWorKdkok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          "]]}, Annotation[#, "Charting`Private`Tag$2931#1"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 180}, {0, 3500}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"e(t)\"", "\"a(t)\"", "\"m(t)\"", "\"s(t)\"", "\"c(t)\"", "\"d(t)\""},
       "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.4444444444444444, 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["2", "3"], ",", 
                    FractionBox["2", "3"], ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8180861956173587`*^9, 3.8182523977789125`*^9, 
  3.8182524422093973`*^9, 3.818335202903455*^9, 3.8184347615786343`*^9, 
  3.8197231072164383`*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"32accbf2-3184-4c31-8f9a-64b12e47cfd9"]
}, Open  ]],

Cell["\<\
The Evaluate command will give you the numerical value of any of the desired \
solution functions at a specified time between t=0 and t=180.  For example, \
executing the next command will tell you the number of deaths that occur \
during this time period and the total number of infections that occur (which \
is u(0)-u(180)).\
\>", "Text",
 CellChangeTimes->{{3.817913933273328*^9, 3.8179139721526837`*^9}, {
   3.817914039137076*^9, 3.8179141140566688`*^9}, {3.8179148676635942`*^9, 
   3.817914868152604*^9}, {3.8184347839843864`*^9, 3.818434827744722*^9}, 
   3.8197225110288305`*^9},ExpressionUUID->"d1d9170f-9c58-46f5-a743-\
fbda350651c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"d", "[", "180", "]"}], "/.", "sample1"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"u", "[", "0", "]"}], "-", 
       RowBox[{"u", "[", "180", "]"}]}], "/.", "sample1"}], "]"}], "}"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.817392417741521*^9, 3.81739242352298*^9}, {
  3.8173930287559676`*^9, 3.81739304836537*^9}, {3.8179140173366795`*^9, 
  3.8179140246086836`*^9}, {3.8183352258361206`*^9, 3.8183352276030684`*^9}, {
  3.8184348526049743`*^9, 3.8184348594553223`*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"7966d57a-25d7-43cb-950d-152938f3f9ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "2632.0376933761227`", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "59162.31211156174`", "}"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.818086200125582*^9, 3.8182524037325892`*^9, 
  3.8182524454766316`*^9, 3.8183352314931784`*^9, 3.818434875818677*^9, 
  3.8197231112316723`*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"575c70b1-bd01-4388-b19e-d36b68576efd"]
}, Open  ]],

Cell["\<\
Hospitalization rates are given by s(t)+c(t),  and we can estimate peak \
hospitalization from a graph of s(t)+c(t):\
\>", "Text",
 CellChangeTimes->{
  3.8179142042493987`*^9},ExpressionUUID->"f1f11fa6-83c9-4dff-9c90-\
95fb29a668aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "t", "]"}], "+", 
      RowBox[{"c", "[", "t", "]"}]}], "/.", "sample1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "80", ",", "120"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Orange"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8179142580969667`*^9, 3.8179143182646503`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"eee97169-0315-4011-a396-50bc17d6dc88"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VV0XAHARSopQSYOhQiSFJBlWKaRMZTr7uolMSUQpIskQ+YQM1z1e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       "]]},
     Annotation[#, "Charting`Private`Tag$3532#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{80, 1035.8430316273016`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{80, 120}, {1035.8430316273016`, 1660.890379473965}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.818086203726467*^9, 3.8197231180429487`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"c38944b5-eaff-421a-bc63-c25204536b5a"]
}, Open  ]],

Cell[TextData[{
 "From this graph it appears that peak hospitalization is about 1600 at \
t=105.  A more precise estimate can be obtained from the following \
\[OpenCurlyDoubleQuote]NMaximize\[CloseCurlyDoubleQuote] command, which asks \
for the maximum between t=80 and t=120. ",
 StyleBox[" Execute the next command.",
  FontColor->RGBColor[1, 0, 0]],
 "\n"
}], "Text",
 CellChangeTimes->{{3.8179143920646477`*^9, 3.81791443956166*^9}, {
  3.817994153442167*^9, 3.8179942138412704`*^9}, {3.8184349051911716`*^9, 
  3.8184350277271547`*^9}, {3.819298080124155*^9, 
  3.819298093489843*^9}},ExpressionUUID->"7cf31a2d-d681-4916-909d-\
b8a142821fd2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NMaximize", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "t", "]"}], "+", 
      RowBox[{"c", "[", "t", "]"}]}], "/.", "sample1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "80", ",", "120"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.817914444412652*^9, 3.8179144648349323`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"d581e644-2771-4696-a62e-69f714b57c95"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1660.8903828976327`", ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "105.13777156063817`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8180862417931137`*^9, 3.819723130105483*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"042fe86e-7cdb-4113-9eff-6efe2a5df60e"]
}, Open  ]],

Cell["\<\
Peak ICU use is  obtained approximately from the next line, where we have \
chosen the interval t=100 to t=140 based on our graph of c(t) above.\
\>", "Text",
 CellChangeTimes->{{3.818086258994028*^9, 3.818086296642007*^9}, {
  3.8184350651271744`*^9, 
  3.818435096103159*^9}},ExpressionUUID->"4fda1a0e-e9f5-4942-949c-\
e6b2cb675825"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{
  3.8179145433206377`*^9},ExpressionUUID->"ac1252ee-df6d-4ca5-9f66-\
863ea46a7d7f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NMaximize", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"c", "[", "t", "]"}], "/.", "sample1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "100", ",", "140"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8180863073459477`*^9, 3.8180863249648113`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"3f1dff47-9f6a-4825-bf1f-3d2bcf2f5af6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"655.4282507089723`", ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "112.91518414795009`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8180863260331216`*^9, 3.819723133699342*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"d86060a1-64a9-42b2-b05f-9ab2054b3f33"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Repeat the above computations two more times, using the \[Beta] \
values corresponding to reproductive numbers ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "10e10f68-dc81-4367-9ac3-a40f2f8f4db7"],
 StyleBox["=1.5 and 2.2.  Begin by copying the command defining sample1, \
changing the value of \[Beta] where it appears in the equations for u\
\[CloseCurlyQuote](t) and e\[CloseCurlyQuote](t), and renaming \
\[OpenCurlyDoubleQuote]sample1\[CloseCurlyDoubleQuote] to a new name of your \
choosing.",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 StyleBox["Give the requested graphs, determine total deaths, total \
infections, peak hospitalizations and peak ICU usage.",
  FontColor->RGBColor[1, 0, 0]],
 "\n\n"
}], "Text",
 CellChangeTimes->{{3.817914577808626*^9, 3.8179147140826225`*^9}, {
  3.8179147939611387`*^9, 3.81791479451305*^9}, {3.81894767150174*^9, 
  3.818947683261602*^9}, {3.818947781102104*^9, 3.818947808701532*^9}, {
  3.8197232066871014`*^9, 
  3.819723219762375*^9}},ExpressionUUID->"35be1d6c-3f4f-4384-94ec-\
f06d13977884"],

Cell[TextData[StyleBox["VACCINE MODELS",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.818347972984499*^9, 
  3.8183479779705906`*^9}},ExpressionUUID->"b7c82171-4d57-4d99-9b0b-\
e73ae1c0e547"],

Cell[TextData[{
 "\n",
 StyleBox["----------------------------------SAMPLE: 14 day delay, \
\[Beta]=0.33 (",
  FontSize->16,
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontSize->16,
  FontWeight->"Bold",ExpressionUUID->"f23467fd-33d4-49c0-b839-867e3caddd40"],
 StyleBox["=1.8)----------------------------",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.819983691076009*^9, 3.819983706034399*^9}, {
  3.81998908994309*^9, 
  3.81998909271809*^9}},ExpressionUUID->"106baad3-f532-4d67-9e77-\
15906ce113a9"],

Cell[TextData[{
 "Part (j):  Next we consider a fast acting vaccine consisting of a single \
shot which takes effect after 14 days, with  \[Beta]=0.33 corresponding to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],ExpressionUUID->
  "dad18610-77b1-4878-b23c-8d168101842b"],
 "=1.8.  For the first 14 days after vaccination begins, there is no transfer \
from the u to uv compartments, and so the ev, av, sv, and cv compartments \
also remain unpopulated during this time.  We solve the following system of \
ODEs to determine the values of our variables for the first 14 days; note \
that \[Nu]u[t-14] is set equation to 0 for 0<t<14.  The parameter values for \
the progression, mortality, and recovery rates (for the non-vaccinated \
compartments) from sample1 are used, while the progression, mortality, and \
recovery rates for the vaccinated compartments are halved and doubled, \
respectively.  \n\nThe solutions in  solstart provide the initial history \
functions when we model our fast acting vaccine with a 14 day delay with a \
system that includes delay differential equations for u\[CloseCurlyQuote](t) \
and uv\[CloseCurlyQuote](t).  We use \[Sigma]=1/2 as requested in the \
equation for uv\[CloseCurlyQuote](t). ",
 StyleBox[" Execute the next line, noting that although we have suppressed \
the printing of any output, it determines numerical values for all 13 \
functions (all except r(t) which we may safely suppress)  in the system for \
0<t<14.  ",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{
  3.817994314594264*^9, {3.817994492425251*^9, 3.8179946022210207`*^9}, {
   3.8179948001932173`*^9, 3.8179948069062757`*^9}, {3.8179948503866177`*^9, 
   3.817994852123828*^9}, {3.817994927352211*^9, 3.817994963391637*^9}, {
   3.8179950167092*^9, 3.8179950932515163`*^9}, {3.818087167690917*^9, 
   3.8180871734372635`*^9}, {3.818260244343832*^9, 3.818260245021054*^9}, {
   3.818348406859928*^9, 3.8183484642698755`*^9}, {3.8184375800121913`*^9, 
   3.8184375984501715`*^9}, {3.818945664301982*^9, 3.8189456727769003`*^9}, {
   3.8192981427825394`*^9, 3.819298147504845*^9}, {3.819983554893968*^9, 
   3.819983618771204*^9}, 
   3.81998365716431*^9},ExpressionUUID->"a8faa265-4750-4e2b-99df-\
ed79574f1c85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solstart", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", "t", "]"}], ",", 
      RowBox[{"e", "[", "t", "]"}], ",", 
      RowBox[{"a", "[", "t", "]"}], ",", 
      RowBox[{"m", "[", "t", "]"}], ",", 
      RowBox[{"s", "[", "t", "]"}], ",", 
      RowBox[{"c", "[", "t", "]"}], ",", 
      RowBox[{"d", "[", "t", "]"}], ",", 
      RowBox[{"uv", "[", "t", "]"}], ",", 
      RowBox[{"ev", "[", "t", "]"}], ",", 
      RowBox[{"av", "[", "t", "]"}], ",", 
      RowBox[{"mv", "[", "t", "]"}], ",", 
      RowBox[{"sv", "[", "t", "]"}], ",", 
      RowBox[{"cv", "[", "t", "]"}]}], "}"}], "/.", 
    RowBox[{
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"u", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", ".33"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".165", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["e", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{".33", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "+", 
           RowBox[{".165", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".333", 
            RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".555"}], 
            RowBox[{"a", "[", "t", "]"}]}], "+", 
           RowBox[{".333", 
            RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"m", "[", "t", "]"}]}], "/", "6"}], "+", 
           RowBox[{".333", 
            RowBox[{"a", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"s", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"s", "[", "t", "]"}]}], "/", "4"}], "+", 
           RowBox[{".0833", 
            RowBox[{"m", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c", "[", "t", "]"}]}], "/", "14"}], "+", 
           RowBox[{".05", 
            RowBox[{"s", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"uv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", ".33"}], "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".165", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["ev", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{".33", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "+", 
           RowBox[{".165", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".333", 
            RowBox[{
             RowBox[{"ev", "[", "t", "]"}], "/", "2"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["av", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".6105"}], 
            RowBox[{"av", "[", "t", "]"}]}], "+", 
           RowBox[{".1665", 
            RowBox[{"ev", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"mv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".2059"}], 
            RowBox[{"mv", "[", "t", "]"}]}], "+", 
           RowBox[{".1665", 
            RowBox[{"av", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"sv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".3875"}], 
            RowBox[{"sv", "[", "t", "]"}]}], "+", 
           RowBox[{".04165", 
            RowBox[{"mv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"cv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".1268"}], 
            RowBox[{"cv", "[", "t", "]"}]}], "+", 
           RowBox[{".025", 
            RowBox[{"sv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{".0107", 
            RowBox[{"c", "[", "t", "]"}]}], "+", 
           RowBox[{".00167", 
            RowBox[{"m", "[", "t", "]"}]}], "+", 
           RowBox[{".025", 
            RowBox[{"s", "[", "t", "]"}]}], "+", 
           RowBox[{".000835", 
            RowBox[{"mv", "[", "t", "]"}]}], "+", 
           RowBox[{".0125", 
            RowBox[{"sv", "[", "t", "]"}]}], "+", 
           RowBox[{".00535", 
            RowBox[{"cv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"u", "[", "0", "]"}], "\[Equal]", "90900"}], ",", 
         RowBox[{
          RowBox[{"e", "[", "0", "]"}], "\[Equal]", "100"}], ",", 
         RowBox[{
          RowBox[{"a", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"m", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"s", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"c", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"d", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"uv", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"av", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"ev", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"mv", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"sv", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"cv", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "u", ",", "e", ",", "a", ",", "m", ",", "s", ",", "c", ",", "d", ",", 
         "uv", ",", "ev", ",", "av", ",", "mv", ",", "sv", ",", "cv"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "14"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8182679521338863`*^9, 3.818268064971338*^9}, {
  3.818438365803026*^9, 3.818438394216857*^9}, {3.8184384535518627`*^9, 
  3.818438459520847*^9}, {3.818946927303177*^9, 3.818946927801189*^9}, {
  3.8189473940211506`*^9, 3.8189473941841383`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"d071339b-bd38-4147-82a6-494f20e82a2e"],

Cell[TextData[{
 "We use these initial history functions to solve the full delay differential \
equation system, first assuming  that 1/2 percent of the unvaccinated \
population is vaccinated each day, so that \[Nu]=0.005. ",
 StyleBox[" Execute the next line:",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{
  3.8183480927219744`*^9},ExpressionUUID->"67722a7d-f111-4d8f-a1ba-\
d263fdbe171a"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"sample2delay14", "=", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", " ", ".33"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", "[", "t", "]"}], "+", 
             RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "-", 
          RowBox[{".165", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"av", "[", "t", "]"}], "+", 
             RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "-", 
          RowBox[{".005", "\[IndentingNewLine]", 
           RowBox[{"u", "[", 
            RowBox[{"t", "-", "14"}], "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["e", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
         RowBox[{
          RowBox[{".33", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", "[", "t", "]"}], "+", 
             RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "+", 
          RowBox[{".165", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"av", "[", "t", "]"}], "+", 
             RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "-", 
          RowBox[{".333", 
           RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".555"}], 
           RowBox[{"a", "[", "t", "]"}]}], "+", 
          RowBox[{".333", 
           RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"m", "[", "t", "]"}]}], "/", "6"}], "+", 
          RowBox[{".333", 
           RowBox[{"a", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"s", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"s", "[", "t", "]"}]}], "/", "4"}], "+", 
          RowBox[{".0833", 
           RowBox[{"m", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"c", "[", "t", "]"}]}], "/", "14"}], "+", 
          RowBox[{".05", 
           RowBox[{"s", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"uv", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", " ", ".33"}], "*", 
           RowBox[{"(", ".5", ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", "[", "t", "]"}], "+", 
             RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"uv", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "-", 
          RowBox[{".165", "*", 
           RowBox[{"(", ".5", ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"av", "[", "t", "]"}], "+", 
             RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"uv", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "+", 
          RowBox[{".005", 
           RowBox[{"u", "[", 
            RowBox[{"t", "-", "14"}], "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["ev", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
         RowBox[{
          RowBox[{".33", "*", 
           RowBox[{"(", ".5", ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", "[", "t", "]"}], "+", 
             RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"uv", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "+", 
          RowBox[{".165", "*", 
           RowBox[{"(", ".5", ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"av", "[", "t", "]"}], "+", 
             RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{
            RowBox[{"uv", "[", "t", "]"}], "/", 
            RowBox[{"(", "100000", ")"}]}]}], "-", 
          RowBox[{".333", 
           RowBox[{
            RowBox[{"ev", "[", "t", "]"}], "/", "2"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["av", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".6105"}], 
           RowBox[{"av", "[", "t", "]"}]}], "+", 
          RowBox[{".1665", 
           RowBox[{"ev", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"mv", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".2059"}], 
           RowBox[{"mv", "[", "t", "]"}]}], "+", 
          RowBox[{".1665", 
           RowBox[{"av", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"sv", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".3875"}], 
           RowBox[{"sv", "[", "t", "]"}]}], "+", 
          RowBox[{".04165", 
           RowBox[{"mv", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"cv", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", ".1268"}], 
           RowBox[{"cv", "[", "t", "]"}]}], "+", 
          RowBox[{".025", 
           RowBox[{"sv", "[", "t", "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "'"}], "[", "t", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{".0107", 
           RowBox[{"c", "[", "t", "]"}]}], "+", 
          RowBox[{".00167", 
           RowBox[{"m", "[", "t", "]"}]}], "+", 
          RowBox[{".025", 
           RowBox[{"s", "[", "t", "]"}]}], "+", 
          RowBox[{".000835", 
           RowBox[{"mv", "[", "t", "]"}]}], "+", 
          RowBox[{".0125", 
           RowBox[{"sv", "[", "t", "]"}]}], "+", 
          RowBox[{".00535", 
           RowBox[{"cv", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"u", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"e", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"a", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"s", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"c", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "6", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"uv", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "8", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"ev", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "9", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"av", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "10", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"mv", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "11", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"sv", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "12", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"cv", "[", 
          RowBox[{"t", "/;", 
           RowBox[{"t", "\[LessEqual]", "14"}]}], "]"}], "\[Equal]", 
         RowBox[{"solstart", "[", 
          RowBox[{"[", "13", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "u", ",", "e", ",", "a", ",", "m", ",", "s", ",", "c", ",", "d", ",", 
        "uv", ",", "ev", ",", "av", ",", "mv", ",", "sv", ",", "cv"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "180"}], "}"}]}], "]"}]}], ";"}], 
  "Input"]], "Text",
 CellChangeTimes->{{3.8185005333961287`*^9, 3.81850055741133*^9}, {
   3.8189469394491816`*^9, 3.818946984321149*^9}, {3.8189474054572754`*^9, 
   3.81894743574942*^9}, 3.8199110335953684`*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"e50bc56f-1c01-4aa6-b951-f0aedbd4d16a"],

Cell[TextData[StyleBox["Execute the next command to plot the graphs of d(t), \
s(t), c(t), sv(t), and cv(t) for 0<t<180.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.8180825649305353`*^9, 3.8180825701566114`*^9}, {
  3.8180826769463425`*^9, 3.818082761265318*^9}, {3.818500586786128*^9, 
  3.8185005905851164`*^9}},ExpressionUUID->"2d1c658d-67b9-4e93-b69e-\
52c6f056accd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"d", "[", "t", "]"}], ",", 
       RowBox[{"s", "[", "t", "]"}], ",", 
       RowBox[{"c", "[", "t", "]"}], ",", 
       RowBox[{"sv", "[", "t", "]"}], ",", 
       RowBox[{"cv", "[", "t", "]"}]}], "}"}], "/.", "sample2delay14"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "180"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", " ", "Yellow", ",", "Red", ",", 
      RowBox[{"Darker", "[", "Yellow", "]"}], ",", 
      RowBox[{"Darker", "[", "Red", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "180"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1000"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<d(t)\>\"", ",", "\"\<s(t)\>\"", ",", "\"\<c(t)\>\"", ",", 
      "\"\<sv(t)\>\"", ",", "\"\<cv(t)\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8174721345125732`*^9, 3.817472147184827*^9}, {
  3.817472231778614*^9, 3.81747227295018*^9}, {3.817483385014497*^9, 
  3.817483411810777*^9}, {3.817486556450085*^9, 3.8174866398590384`*^9}, {
  3.817487216980958*^9, 3.8174872381992235`*^9}, {3.8180827958588867`*^9, 
  3.818082842507326*^9}, {3.8180828866633244`*^9, 3.8180829133953085`*^9}, {
  3.818082995581293*^9, 3.8180829961000414`*^9}, {3.81809190968649*^9, 
  3.818091910386466*^9}, {3.8183482727159395`*^9, 3.8183482731819835`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"3583c73d-06f8-4c91-9ac8-44167d12ed0d"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwV1Wk0FXoXBnB0zRS65sgcZZ4V/o8hJFwhQmQ6x1CGiiJFKtRRSikqNCDF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          "]]}, Annotation[#, "Charting`Private`Tag$3538#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 1, 0]], 
         LineBox[CompressedData["
1:eJwV1nk8VVsbB3BCKIRC0iCkS+ZZxf4ZS5TpnH0OpYzHfAZUKpd6QzdTFKWB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          "]]}, Annotation[#, "Charting`Private`Tag$3538#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwt13k8VO/3AHDKvpQl2bMrPpZPkcjyHLtsyTZzZ+xmLoqhLCG0kcoSolLR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          "]]}, Annotation[#, "Charting`Private`Tag$3538#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJxF1nk8VP/3OHCVpeyyZJ+xpMg6dmVeZ2zZZTcz9mWsoawhtFDZU0pRFImS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          "]]}, Annotation[#, "Charting`Private`Tag$3538#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0]], 
         LineBox[CompressedData["
1:eJxF1nc4l9/7AHBJaQhlZGWrT7I38dy3nT1CeA8SokFJhcwUsitKCBUpRDRI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          "]]}, Annotation[#, "Charting`Private`Tag$3538#1"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 180}, {-1, 1000}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"d(t)\"", "\"s(t)\"", "\"c(t)\"", "\"sv(t)\"", "\"cv(t)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.4444444444444444, 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["2", "3"], ",", 
                    FractionBox["2", "3"], ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    Rational[2, 3], 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.4444444444444444, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["2", "3"], ",", "0", ",", "0"}], "]"}], 
                    NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[2, 3], 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[
                    Rational[2, 3], 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.817472275542959*^9, 3.817472694199421*^9, {3.8174833748722258`*^9, 
   3.817483413246129*^9}, {3.8174865620602064`*^9, 3.8174866119672966`*^9}, 
   3.8174866421242895`*^9, {3.8174872223733587`*^9, 3.8174872391105394`*^9}, 
   3.818082924519579*^9, 3.818082998944601*^9, 3.8180873570915504`*^9, 
   3.8180890658194447`*^9, {3.8180918942043447`*^9, 3.81809191136106*^9}, {
   3.818092162194085*^9, 3.818092177225232*^9}, 3.818268250566791*^9, 
   3.8183482749984503`*^9, 3.818946996049183*^9, 3.818947445912113*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"7d522ea3-6562-4dec-b844-d7109e693cc1"]
}, Open  ]],

Cell[TextData[{
 StyleBox["The next commands determine total deaths, total infections, peak \
hospitalization and peak ICU usage",
  FontColor->RGBColor[1, 0, 0]],
 "."
}], "Text",
 CellChangeTimes->{{3.817472185826338*^9, 3.8174721873555417`*^9}, 
   3.817472227357518*^9, {3.819911054344301*^9, 
   3.8199110816565285`*^9}},ExpressionUUID->"a8965629-1fdf-4124-bdfa-\
9cbd583bdf52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"d", "[", "180", "]"}], "/.", "sample2delay14"}], "]"}], "}"}], 
   ",", " ", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"u", "[", "0", "]"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "[", "180", "]"}], "+", 
         RowBox[{"uv", "[", "180", "]"}]}], ")"}]}], "/.", "sample2delay14"}],
      "]"}], "}"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.817487277140793*^9, 3.8174873074502125`*^9}, {
  3.8180831711952953`*^9, 3.81808318736229*^9}, {3.8180832405693007`*^9, 
  3.8180832815637817`*^9}, {3.818348210049946*^9, 3.818348217547948*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"78a2f32b-7a39-4c07-aca0-88f16e65ebe3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "866.4389658194859`", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "23668.216560329456`", "}"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.817487310825582*^9, 3.8180831892644186`*^9, 
  3.818083283215046*^9, 3.818087365105889*^9, 3.8180874665551825`*^9, 
  3.8180890716190295`*^9, 3.8180918993642893`*^9, 3.818092181693633*^9, 
  3.8181632281970463`*^9, 3.8182602658813715`*^9, 3.8182682551737814`*^9, 
  3.8182684052366314`*^9, 3.818348225226326*^9, 3.8184386420345316`*^9, 
  3.8189470003031693`*^9, 3.818947449014664*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"e55e35ba-58dc-4898-af25-546c8b76899a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NMaximize", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "t", "]"}], "+", 
      RowBox[{"c", "[", "t", "]"}], "+", 
      RowBox[{"sv", "[", "t", "]"}], "+", 
      RowBox[{"cv", "[", "t", "]"}]}], "/.", "sample2delay14"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "50", ",", "100"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.818087496370804*^9, 3.818087499802902*^9}, {
  3.818088533163801*^9, 3.8180885377878084`*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"5e65bd94-64b1-4772-847e-03ab414c35db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"457.7382265706116`", ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "94.76812218095797`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.818087507517948*^9, 3.8180885414273305`*^9, 
  3.8180919210214353`*^9, 3.818092189460955*^9, 3.8182602709398947`*^9, 
  3.818268344180202*^9, 3.8182684399532895`*^9, 3.8183482316287203`*^9, 
  3.818438647754779*^9, 3.8189470034699607`*^9, 3.8189474516923323`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"89407144-de79-43b6-9a04-5000a64edff6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NMaximize", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "t", "]"}], "+", 
      RowBox[{"cv", "[", "t", "]"}]}], "/.", "sample2delay14"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "50", ",", "120"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.819910984095297*^9, 3.8199109913596935`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"270d8217-1c3a-406f-ad0c-4730a027b8a4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"181.2419200304084`", ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "102.51118800740464`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8199110056412544`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"8b4a6bfe-2437-4f74-96b8-7f7c654a49eb"]
}, Open  ]],

Cell[TextData[{
 StyleBox["----------------------------------SAMPLE: 30 day delay, \
\[Beta]=0.33 (",
  FontSize->16,
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontSize->16,
  FontWeight->"Bold",ExpressionUUID->"ee52e11b-ddde-41cf-8dec-358cc340d354"],
 StyleBox["=1.8)--------------------------------",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{
  3.8189462144629374`*^9, {3.8189498157089167`*^9, 3.8189498176929183`*^9}, {
   3.819911712562949*^9, 3.819911723219919*^9}, {3.81998908330408*^9, 
   3.8199890849350796`*^9}},ExpressionUUID->"fac5bd2d-f448-4c9c-9dd5-\
ae2274502279"],

Cell[TextData[{
 "Now we repeat the same calculations, but for a 30 day delay and \
\[Beta]=0.33 corresponding to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "0"], "=", "1.8", " "}], TraditionalForm]],
  ExpressionUUID->"9841d3c7-bc72-41eb-89ae-780dd73a5489"],
 ". ",
 StyleBox[" Execute the next lines, the first of which sets \[Nu]u[t-30] \
equal to 0 and solves the resulting system for 0<t<30.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.818946153135174*^9, 3.818946183725586*^9}, 
   3.8189462237092505`*^9, {3.819298193966101*^9, 
   3.8192982659220934`*^9}},ExpressionUUID->"008a876a-087b-4573-b127-\
96757eec3eb3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solstart30", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", "t", "]"}], ",", 
      RowBox[{"e", "[", "t", "]"}], ",", 
      RowBox[{"a", "[", "t", "]"}], ",", 
      RowBox[{"m", "[", "t", "]"}], ",", 
      RowBox[{"s", "[", "t", "]"}], ",", 
      RowBox[{"c", "[", "t", "]"}], ",", 
      RowBox[{"d", "[", "t", "]"}], ",", 
      RowBox[{"uv", "[", "t", "]"}], ",", 
      RowBox[{"ev", "[", "t", "]"}], ",", 
      RowBox[{"av", "[", "t", "]"}], ",", 
      RowBox[{"mv", "[", "t", "]"}], ",", 
      RowBox[{"sv", "[", "t", "]"}], ",", 
      RowBox[{"cv", "[", "t", "]"}]}], "}"}], "/.", 
    RowBox[{
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"u", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", ".33"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".165", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["e", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{".33", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "+", 
           RowBox[{".165", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".333", 
            RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".555"}], 
            RowBox[{"a", "[", "t", "]"}]}], "+", 
           RowBox[{".333", 
            RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"m", "[", "t", "]"}]}], "/", "6"}], "+", 
           RowBox[{".333", 
            RowBox[{"a", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"s", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"s", "[", "t", "]"}]}], "/", "4"}], "+", 
           RowBox[{".0833", 
            RowBox[{"m", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c", "[", "t", "]"}]}], "/", "14"}], "+", 
           RowBox[{".05", 
            RowBox[{"s", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"uv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", ".33"}], "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".165", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["ev", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{".33", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "+", 
           RowBox[{".165", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".333", 
            RowBox[{
             RowBox[{"ev", "[", "t", "]"}], "/", "2"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["av", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".6105"}], 
            RowBox[{"av", "[", "t", "]"}]}], "+", 
           RowBox[{".1665", 
            RowBox[{"ev", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"mv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".2059"}], 
            RowBox[{"mv", "[", "t", "]"}]}], "+", 
           RowBox[{".1665", 
            RowBox[{"av", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"sv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".3875"}], 
            RowBox[{"sv", "[", "t", "]"}]}], "+", 
           RowBox[{".04165", 
            RowBox[{"mv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"cv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".1268"}], 
            RowBox[{"cv", "[", "t", "]"}]}], "+", 
           RowBox[{".025", 
            RowBox[{"sv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{".0107", 
            RowBox[{"c", "[", "t", "]"}]}], "+", 
           RowBox[{".00167", 
            RowBox[{"m", "[", "t", "]"}]}], "+", 
           RowBox[{".025", 
            RowBox[{"s", "[", "t", "]"}]}], "+", 
           RowBox[{".000835", 
            RowBox[{"mv", "[", "t", "]"}]}], "+", 
           RowBox[{".0125", 
            RowBox[{"sv", "[", "t", "]"}]}], "+", 
           RowBox[{".00535", 
            RowBox[{"cv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"u", "[", "0", "]"}], "\[Equal]", "90900"}], ",", 
         RowBox[{
          RowBox[{"e", "[", "0", "]"}], "\[Equal]", "100"}], ",", 
         RowBox[{
          RowBox[{"a", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"m", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"s", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"c", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"d", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"uv", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"av", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"ev", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"mv", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"sv", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"cv", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "u", ",", "e", ",", "a", ",", "m", ",", "s", ",", "c", ",", "d", ",", 
         "uv", ",", "ev", ",", "av", ",", "mv", ",", "sv", ",", "cv"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "30"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"1466ec87-a75a-4457-b40a-e1339e62a141"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sample2delay30", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"u", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", ".33"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".165", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".005", "\[IndentingNewLine]", 
            RowBox[{"u", "[", 
             RowBox[{"t", "-", "30"}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["e", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{".33", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "+", 
           RowBox[{".165", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".333", 
            RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".555"}], 
            RowBox[{"a", "[", "t", "]"}]}], "+", 
           RowBox[{".333", 
            RowBox[{"e", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"m", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"m", "[", "t", "]"}]}], "/", "6"}], "+", 
           RowBox[{".333", 
            RowBox[{"a", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"s", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"s", "[", "t", "]"}]}], "/", "4"}], "+", 
           RowBox[{".0833", 
            RowBox[{"m", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"c", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"c", "[", "t", "]"}]}], "/", "14"}], "+", 
           RowBox[{".05", 
            RowBox[{"s", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"uv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", " ", ".33"}], "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".165", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "+", 
           RowBox[{".005", 
            RowBox[{"u", "[", 
             RowBox[{"t", "-", "30"}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["ev", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", " ", 
          RowBox[{
           RowBox[{".33", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"a", "[", "t", "]"}], "+", 
              RowBox[{"m", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "+", 
           RowBox[{".165", "*", 
            RowBox[{"(", ".5", ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"av", "[", "t", "]"}], "+", 
              RowBox[{"mv", "[", "t", "]"}]}], ")"}], "*", 
            RowBox[{
             RowBox[{"uv", "[", "t", "]"}], "/", 
             RowBox[{"(", "100000", ")"}]}]}], "-", 
           RowBox[{".333", 
            RowBox[{
             RowBox[{"ev", "[", "t", "]"}], "/", "2"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["av", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".6105"}], 
            RowBox[{"av", "[", "t", "]"}]}], "+", 
           RowBox[{".1665", 
            RowBox[{"ev", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"mv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".2059"}], 
            RowBox[{"mv", "[", "t", "]"}]}], "+", 
           RowBox[{".1665", 
            RowBox[{"av", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"sv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".3875"}], 
            RowBox[{"sv", "[", "t", "]"}]}], "+", 
           RowBox[{".04165", 
            RowBox[{"mv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"cv", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", ".1268"}], 
            RowBox[{"cv", "[", "t", "]"}]}], "+", 
           RowBox[{".025", 
            RowBox[{"sv", "[", "t", "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{
           RowBox[{".0107", 
            RowBox[{"c", "[", "t", "]"}]}], "+", 
           RowBox[{".00167", 
            RowBox[{"m", "[", "t", "]"}]}], "+", 
           RowBox[{".025", 
            RowBox[{"s", "[", "t", "]"}]}], "+", 
           RowBox[{".000835", 
            RowBox[{"mv", "[", "t", "]"}]}], "+", 
           RowBox[{".0125", 
            RowBox[{"sv", "[", "t", "]"}]}], "+", 
           RowBox[{".00535", 
            RowBox[{"cv", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"u", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"e", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"a", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"m", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"s", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "5", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "6", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "7", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"uv", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "8", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"ev", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "9", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"av", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "10", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"mv", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "11", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"sv", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "12", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"cv", "[", 
           RowBox[{"t", "/;", 
            RowBox[{"t", "\[LessEqual]", "30"}]}], "]"}], "\[Equal]", 
          RowBox[{"solstart30", "[", 
           RowBox[{"[", "13", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "u", ",", "e", ",", "a", ",", "m", ",", "s", ",", "c", ",", "d", ",", 
         "uv", ",", "ev", ",", "av", ",", "mv", ",", "sv", ",", "cv"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "180"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8189463083582544`*^9, 3.818946310787102*^9}, {
  3.818946666608209*^9, 
  3.8189466680782213`*^9}},ExpressionUUID->"fde58412-1f3a-4277-96f8-\
8e58c9f64951"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"d", "[", "t", "]"}], ",", 
       RowBox[{"s", "[", "t", "]"}], ",", 
       RowBox[{"c", "[", "t", "]"}], ",", 
       RowBox[{"sv", "[", "t", "]"}], ",", 
       RowBox[{"cv", "[", "t", "]"}]}], "}"}], "/.", "sample2delay30"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "180"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", " ", "Yellow", ",", "Red", ",", 
      RowBox[{"Darker", "[", "Yellow", "]"}], ",", 
      RowBox[{"Darker", "[", "Red", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "180"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1500"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<d(t)\>\"", ",", "\"\<s(t)\>\"", ",", "\"\<c(t)\>\"", ",", 
      "\"\<sv(t)\>\"", ",", "\"\<cv(t)\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.818946673799327*^9, 3.818946673803156*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"555b1c8c-7a4c-4da2-9f3a-742316f43f20"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         LineBox[CompressedData["
1:eJwV1Xc0198fB/CPZFOojEh2qYiPXbjPkBFJKImKz1JCg6xEktGStwYNklSI
ComWryQhRagoSRnJpsyU3+f31z2P8zzn3td9ve45V4mxz4k9h0ajqfPQaP9f
D7zVWlZc/9aseYl8TL3XFhOzwUx9hmUuEUsL9ZIMvW7Wfs3gvKrlU7LZt/1u
47F3Zo6sN/yiui8Jw+/VnfCrA2b5IZEv+CxrSZEfm5VxnoecqJQpi8x5R+gH
6sXv0CXIo/oDaTP094S9PSvW68US0vupJjz0STN5HlvUWJa9jCzuUnEft2gl
EXeGso7d1SF2Q+HGAbVfyWJBMXeWrjEpnekVCcn5Rhb5PPgXZb+OfIiSPvzQ
v4Oc+y23zUnYmgzyW/b+pneRlZ13n6UObCT8p/e76U50k80SYc/dBZ2JgkRq
1YEnPYS3z3Hwc6UrMbhYbXg/spcUMhzzLcgO4iA3fmvQop+kxd/v1fnPi3DS
laU0BQeJWJBHTrANm0SqbYrZWztE9Ko7OwvX7SH2702nXaqGiYt/jZZivh9p
lm7SCcwZIeeCGGwfhwOEtd1nz7nTo8Qk1PqoH18gGb5Ku17g/4uck5b+fp4W
TMK/Xmx+5/ibZPQ/X15jHkYElTXFR+hjRHD2p/qvt0fIedYLa/FF4yTheW/e
SONRonjbLXL1xDgJmcuTptNzjOT+HHro0DJB+qO+JlxSiyFGq2IH/Z5Mkj+J
BwQiz8SRCn959TOpU6Rl9yroK50kjvkFO3Ijp4nwHKM4/u+nyW6Dr7W9FjOE
7Vd+jSeEIr9DDs0VVv9LIDbFebf0HDn6RMREQ/Af+X1g71RG+3mSAqM73rWz
5L8ZGd7L91JI0jrvAxauNPSkIO9r6WXSzKCLOVfRoL1000L2z6uEdbPK8mAO
D0aWWX1Uqk4nOZXn2qPk5qBYcCy9QTCDDP/YGU6dnoOUinG7Za43SPiKscL7
/ry48tnbJFfxFjl/T0lliM6HFafSffb75ZJP9f2l/27wgfn1oULC8rtEcbR4
+7xF/DDXGfAT+n2P5Oo5JGlO8EMq1yB0b1s+Gd0iq2W6WwB2R8MOW3wpIEbB
ndX2LQJY9fY5/VZnIal4FMbj+0QQ7TMdJrvEHhLhz+tTD68SgrbRn9ttWsXE
cUbc+FSqEG6rV+oZu5WQVrPb+3MiheFire1aVfWYjL1o/NpjIQrvwsVbLwqX
EUl7UfHDpaJYEyourVZXRrSbLCFmLIYFZfnv9C49Jz6dRek6WvNgviZJasr0
Bdk/p1bbVFQc9cm9yf01lSTCqscm1lYcy0Oi3ux4+oqcOTnXqy5WHLU3c2dP
FFaRHElTyotHAqr2z1doFNaQLuW7IzHjEoh49CZeYvIt+c2pEarTlUSAgK/p
b5F6MudOt5LMAUl0DLn21KXVE0XdpU45fZJ4/e+0wM4378h2i8SCt+0LsDzx
VubfjU2kjnkwQPr1Irz0XrB9dVsLabudcMpTUAoHExVVslM/kf6+nBvZ66Ug
ZJhjo+T5mQgHdjSuLZMCNfmPKTbYSiyPu+h5Fkkj3VrEqFeqnTzONBjLuiaL
ChOR/kNpHaSqx0lstFUWMq+ouiVSneTjqn1qaxcvxlMTpxzzs53k94PbW96c
X4yj8w2/88R2kdUvZR6OnJDDtlSfjfYxP0hm13TQmsAl6JX3kSmu6SM2W+La
AvKWIOfZz+xDjv2kv2KBVV73EhRZ7rkT9rGf6GWuWqTopgDalGDo1p8DpIKx
s5DPbCnyHCkLtXnDZHSoPbgnWhElOL7Me9coWeBn+aBwozJ41P0aP4ROkO5M
4d2OPsrI3DRdXlY/QUpa6+UGYpXx69d8E5vlk8TDfke0epkytjSWktUtkyRz
ZZDTJboKio8NvnYznyZ6vbeHI6RVoePRS/HT/xIXbxHNDd/UUGQmmSP+ggck
aAvd9a8aHi+NWWU8wYMVMdcMWbLq2N9mo527cg5oN3TNIzar41HSQNGBC3OQ
1+buWvBcHUbjW+vDfHnBvzU3anHGMvg43PaKW86HEsuNH3oZGmg9Ufi9uFkQ
N5yTP09EaCD27okYYykhJDC+tc+9ooF9kRVp/C5CYB091KfQqIHsk0uDouuF
IPE0leZssQIpWoYpQm+E4aM7uOKJykrYn5Hjd2sShZzy2chTnasQltcR5ZIg
jqcnf2tMzdHEpg1zvnc/EIfHL7cmjpImnMU1gm5/FkdahaqG+U5NWB33PVWo
IQFl78cNkx810e8bWD31SgIrcrvUOK+1IKBalOwktgBL5BQ4im7a0C8a9u96
sgj+dY5rXXdrw/29QKNvzyKURkeLJwRrY4fP4etqi6Sws7/n8Z8L2thZ82Bs
5T4ppD8rnP+xQRsTRPpvgpo0VD1tH52x1wE/773umisyWHUzUPQPoeP6mNlZ
kXtyYLCixzQd6Dgo5D+d0iaHFJWkNk8POnbVfDTZMk8evBn37leG0FFzXbFm
u788PqX1uiTl01Gf4H4rVXsJTqR4pmqo6GLenuNBS0sV0H3KXmsbvx5OVn9w
4p1VhLydu/SphXpYr5mU3CyrBCdhH1qpsh7cPuSEvdJTQml8XIMK0UPmiU7O
qI8SLsSUBw0F64Ftf/xPRLMSLCON/ov9qYfCDJ/Y4yXKuH5Q1bGoVh8eWzub
606roqCt7JRMqz5sjavp8XmqKN+w49XhPn0IvaTleb1VRafyRTNzYQPYXUk8
FCKuBvVGAc06awN4pDseMbqohlzdPqGf5QYwuDp1Ry5LHSW/81/IPzJEg+Za
nnXdy1Ht6TAbWWWImO16tVtFNPCptndNx0dDVJxQjKa0NfAnU6Uge9wQwraN
+kGHNWC25UK6gZ4RPj5da0RbsAIVRSFHHO8ZwXLpY14925WoDyKGx28a403B
EZZIoyb83qZeufbAGHLZ2XwmM5oQVp+ZffzCGLVvMr3Pq2lh/fuSqpFvxuis
pE88DdHCY1369l0KazCt8lxrRHE1ModVj6xJXoO2yAsfjploI8RH+MVw/Fow
6bPf92XqQGnne4cdvqZwcr5+aqCY2+ey+a8Cw0zxmh7OdqzXg7rKBnI63hQ5
j+Qbqnr0sKqndPWTTFOMp3fdmZbVh8HBLHHZL6aQEZN2Zx3Rh33s4YamjWa4
1qxxepeNAYLuKm21X02Q+OfUbPCQIdizD+8uCQXkjzqcOBC7FgsF5M4/Pwqw
vPILd91ei/J5kaHseKA06OSUb9VaKCpYW+YlA3Hhpeu6hE3QavKxxeQhoPXS
Nm8TZQKnsIm5Hr+AZ09ctqtw6zIbM3S/7LcOzOXBptHfCaT7SgSkGeaImbb6
vJBlDqNJ4QmjPebYOnK9MCTYHNv5dnRv328OOt108cBJc1xdyvMyLcIcJkUJ
ZQIF5lB2sT2mfsUc5k4pD/l4LKD1rGVGv8kcGnV5wVoZFrA6Oz3iYmWBb2Gp
ZjEjlgjUNWlNWmEJsw2UWVulNTwMhr4m6lhi4kJvhW2bNSyNMzoSjCzR2fRI
tGrMGguIYN9JK0uk15nO+6tqg4INTVPHGJbIyH4mveG4DYa9fKUDLlvitNU4
CbOyxd7Eq07OwuuhklT591jLBjAGZqoW9K5HfcuFP49MHFBcOT6WPbIe5bTg
Y1fdHSCaPqyMqfWIcps9mhLGzZ06w30FrdAXPk/xSwk3L3mt/VLdCnzxrtGX
DTah6NjllCCmFX4oRDND5RwhKGO0u6XVCuEGfLplapuRZx4gcK3OGvadenEZ
TGcEKrmbFX6whqjVMh3jQ84woVkcevXFGgYdC+NbY51R+0yyY6jPGlNVy1xs
c5zRb1RQCkEbzKmuEng64owVq0cOfYcNjnkvHhCOdkGW3L5OtQIblJo0fAm6
twWZv32e5563Rfu16PPl2tswuU7mTUWkHe5NZ2juZe7EFxrvyDevjSjaNe/z
7SoG/OX3JUapbALjzjs33OLg7p6qsgsxjgiblyYs5bsXYb9kJ1bu2Yxd/hKX
nfT3Y2yD1dZXu5xA61Jo99YJgLE7ta5rszNsHt/O8PcMQoNsqk+FrgtaKetV
JidCsfhW9NOs5Vuw1yJ+6PuSIyhpX2HvILYVj/xGC09YHYVC07B30MBW6EV4
TuyZioLuBSr3Rrsruk7IxWe+iUbq3F9aSS+2gTwRbqWHxODhutWfYh654ZeW
ivgivTikGJ6UmMnZDqnJ/7C+Lh51n2/G6p52x/IYa7eXeidRtPGq6v6jHuji
bQySunQKI37ONH/WDnyllT97VnkaY1YauwctduLwNjPV+e/OIGugZTLAYBd+
Fi8LuP8uAduu32TuEPXEFdt9S+ZmnkVhgd0u3jhPDFeom6nqJ8JYrmHqxJQn
cpQlJT8dT4RKu/end3u88M1Rd1SyKhGdIns3Xe3wQs1Ktu48fgrDlx7/YXR5
YbQ+qfwb1zPLhLM0fnih3sO38oEAhQWW2bTiXi8cziOabkIUzMN/5L8b8cKq
hysjr4hSuNbPXChAY8DHbtFB/gUUtr/xaDkgz4CT7dKo4KUU9x9xYFpvYeBY
tHzwewMKwQ1DsnquDAx9abZNNqSgIEXVK7oxUJvkdGabEQXf1EbTaQ8G3Awb
vVuMKQjmbpPJYzHQUeMa2GRCYV01441kIAN1R+L175tTKOANNmxLYqBb7c0N
mgOF8yHXRA7VM5CvLqslzaSQO7Xt1bYGBowtQxsecP0yTDLapIkB05/hNCcW
hfHwmGneZgZ691ycPsmm4Ba192fSVwYublbaN+HNre+k4av7gwyUsvMvPfal
kHWl7li/KBMyomlDfYcoPC2dnWLaMjG7r3ihcBwFned6RsvsmPgionEpmutb
L/YE9dozofur4+UM11RV4+h+RyYyi0VlB+MpcBpu9x1xZSIuTjK39iQFie5N
X5LZTNiL5xSGJnBzsfSy11FM2JwIeXz+AoX5HojTfcyEeeic7pYMCooLX9XJ
P2XiX07hFesbFLRrN8rwlzIRQXOaesC1k4l7dvNzJn6V2OUlZHL7Ix/0+kg1
13Ud/0xvUVj85c78qmYmirc+P3I6m4LqTukUjwkm7gzEnu69R8HYczArRo+F
hSHWl4qfcO9zaTjAwYCFEaXSFSJPKSxsHDWTNmKBTiYP7+R6cP1EU9ZaFlyN
2TvnPqOQuZLGU2vOgvi7b8s2llKYNyHhJrmZBQVZqV8NZRQ6z+gLXfNjIdzQ
7Nz9lxQSnoTvKbnFQqyO1fjTtxT86MnGIVksGMo1edPqKNhn5wsZ5XDrsQ+4
acG1cHJ3dnEeC7gUGFPNdcxBx96HD1i4Kru7taGeQriG6t6ichYERibmtjZQ
8El+7VvQxsKyQ590qz9QsA5YvD9Xio3xF8leUm0Uyq/FbkiSYUN+449LTlyb
1I6qhixm49bL3rQErrXVXrdYKLBRHHVnPv9XCrIfD1t8VmNDN8QzcZTrvjVf
pIT12WgzztYu/0bh7Jz0Z97ObHTq8E6adFH4SKmJqCSyETD/x52sPgp3idju
HoqNXeWV0++5Pj7wuyLvHBsM2z5V3n4KdNuKCKNkNlwT9ons4DqBxhzdmMZG
vuF21fkDFKz2pbeE5LLREKCR6jtI4YG9XNbbKjb4HlYyxEYoJAlIrA/j4cCW
KFf1jXHf6+gX90BeDv7sH5pZOE7hx5ecg/58HJyZqhMx49rkgWU6Q4iDhRF2
JWe57vYM+bNBggM/gZxNOhMU1j7+mi+nxEHVxK1zfpPc+fneVXgGDjgugzav
p7nz3XZYv9icA8H2jJkhro0tbOzzLTlY/WNdwsI/3Pplv4fetOEgddMDux1c
G1Uuen/GkQM5/hT6ANdnlh45tdOTgyUXo6r5/1IoEd6QsY3BAcVh7dHg+vuY
1CMnFve8K3967Lg2qr3fbbWbA/nXD+MS/5+HdK5bvZ8D/kxvK5l/FERZ+ds0
DnIwPT3Wbcy14aaIfSqBHCjGLtrtzvVpNZlU6RAOwsUPiaZx/VC8q1AijIMo
q77V/3H97U9+jUg4B94Ku/Ta/7/fj4hvfBEc1Eb0yfLMUjBosJucjeTA3PhO
uxLX/wOAelt5
          "]]}, Annotation[#, "Charting`Private`Tag$2454#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 1, 0]], 
         LineBox[CompressedData["
1:eJwV13c81d8fB/BEQiopSSRdokQDGYXPy55f604rcq+LzBD33oaWFhoi9EVk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          "]]}, Annotation[#, "Charting`Private`Tag$2454#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwt1nk4Vdv/B3BzxhLKVMYSEkUOMqw3ThINMp5zUKaOIY6dXBGRCnUN0XhL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          "]]}, Annotation[#, "Charting`Private`Tag$2454#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJxF1nk4lF3YAHCKkmxZKkthZiqk8lJImnPPYOy7MM/Yl7EVUoRCiyTJEioh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          "]]}, Annotation[#, "Charting`Private`Tag$2454#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0]], 
         LineBox[CompressedData["
1:eJxF13k01P/3OHAqSyVlqYSiSEQUIsrrXvu+yzYzdoMWSyJaLKWUSrKVnSzJ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          "]]}, Annotation[#, "Charting`Private`Tag$2454#1"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 180}, {-1, 1500}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"d(t)\"", "\"s(t)\"", "\"c(t)\"", "\"sv(t)\"", "\"cv(t)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 1, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "1", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.4444444444444444, 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["2", "3"], ",", 
                    FractionBox["2", "3"], ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[
                    Rational[2, 3], 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    Rational[2, 3], 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.4444444444444444, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    FractionBox["2", "3"], ",", "0", ",", "0"}], "]"}], 
                    NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
                    Rational[2, 3], 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[
                    Rational[2, 3], 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.818946679169151*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"0794e3ea-1328-4f17-a75b-6a6889e7c28d"]
}, Open  ]],

Cell[TextData[StyleBox["We determine total deaths, total infections, peak \
hospitalization and peak ICU usage:",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.819911193317026*^9, 
  3.8199112066017637`*^9}},ExpressionUUID->"65ad7a27-d344-45e6-8b36-\
45a31e593b5b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"d", "[", "180", "]"}], "/.", "sample2delay30"}], "]"}], "}"}], 
   ",", " ", 
   RowBox[{"{", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"u", "[", "0", "]"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", "[", "180", "]"}], "+", 
         RowBox[{"uv", "[", "180", "]"}]}], ")"}]}], "/.", "sample2delay30"}],
      "]"}], "}"}]}], "}"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"b0f35513-5b12-4bff-bc99-8f5f1f1c2493"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "1151.7830855059026`", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "30290.69544585578`", "}"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8189467231123247`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"bd4c3c8f-e1cc-491a-b1e2-c21ea9450bf9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NMaximize", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "[", "t", "]"}], "+", 
      RowBox[{"c", "[", "t", "]"}], "+", 
      RowBox[{"sv", "[", "t", "]"}], "+", 
      RowBox[{"cv", "[", "t", "]"}]}], "/.", "sample2delay30"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "50", ",", "130"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"da652471-a9d5-46db-b077-5e4e0ac81fa3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"687.8667838987469`", ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "93.10867745937905`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.818946837957559*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"7dcdc904-ee8b-4b99-bb6c-956996d31ea0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NMaximize", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "t", "]"}], "+", 
      RowBox[{"cv", "[", "t", "]"}]}], "/.", "sample2delay30"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "50", ",", "120"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.819910928407035*^9, 3.819910946939397*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"7dd33404-e695-4809-bb67-51fcec68be6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"270.7317354973284`", ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "100.76893738396346`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8199109491256886`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"cb911aba-fda2-4e66-a703-b6db9b2e5733"]
}, Open  ]],

Cell[TextData[{
 StyleBox["----------------------------------14 day delay, \[Beta]=0.28 (",
  FontSize->16,
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontSize->16,
  FontWeight->"Bold",ExpressionUUID->"4e83f669-994b-48cb-90be-f345652d1f8d"],
 StyleBox["=1.5)--------------------------------------------",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.818521884423165*^9, 3.818521957439576*^9}, {
  3.8189498241656895`*^9, 
  3.8189498254615793`*^9}},ExpressionUUID->"c122ecf9-e79d-4755-91d5-\
112723aa5357"],

Cell[TextData[{
 "Repeat these calculations for a 14 day delay vaccine, changing  the \[Beta] \
value, now to correspond to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],ExpressionUUID->
  "3fc8ba37-2f76-4ba1-98e1-92f0251a4a69"],
 "=1.5.  ",
 StyleBox["Copy the command for \[OpenCurlyDoubleQuote]solstart\
\[CloseCurlyDoubleQuote], renaming it solstartR15 and changing the \[Beta] \
value accordingly.\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Keep in mind that",
  FontColor->GrayLevel[0]],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Beta]", "*"], "=", 
    FractionBox["1", "2"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "9fdd5188-34f0-48d1-8db4-ac178cca7336"],
 "\[Beta] also changes when \[Beta] is changed, and that \[Beta] and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Beta]", "*"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "506cd259-3e35-40d9-af53-8fcf7191608d"],
 " appear in the equations for u\[CloseCurlyQuote](t), \
uv\[CloseCurlyQuote](t), e\[CloseCurlyQuote](t) and ev\[CloseCurlyQuote](t)."
}], "Text",
 CellChangeTimes->{{3.8183483247779427`*^9, 3.8183483454659386`*^9}, {
   3.818348495860173*^9, 3.8183485209300313`*^9}, 3.8183486338980374`*^9, {
   3.818521599991661*^9, 3.8185216420261865`*^9}, {3.818947050127802*^9, 
   3.8189470506937723`*^9}, 3.8189470836986566`*^9, {3.81894747824819*^9, 
   3.8189474784057784`*^9}, {3.8189481346930723`*^9, 
   3.8189481527167406`*^9}, {3.8190408974237847`*^9, 
   3.8190411510144825`*^9}},ExpressionUUID->"81259012-1f36-4e2f-9c1b-\
f7125f124fce"],

Cell["", "Text",
 CellChangeTimes->{{3.81852149743042*^9, 3.818521587232191*^9}, 
   3.8185216508571997`*^9},ExpressionUUID->"56feb663-be0b-410f-b1e6-\
8029b6ad4180"],

Cell[TextData[StyleBox["Next copy the command for ``sample2delay14\
\[CloseCurlyDoubleQuote], renaming it, changing the \[Beta] value, and using \
solstartR15 for each initial history function.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.8185216847511797`*^9, 3.818521761735282*^9}, {
  3.818947960285578*^9, 3.8189479625813046`*^9}, {3.8189479970213003`*^9, 
  3.8189479974560943`*^9}},ExpressionUUID->"25db9940-f332-4900-9fcb-\
ca7b2f350080"],

Cell[TextData[{
 "\n",
 StyleBox["Give the requested graphs, determine the total number of deaths, \
total infections, and peak hospitalization and ICU usage.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.818948025316077*^9, 3.818948084605076*^9}, {
  3.8199112642820454`*^9, 
  3.8199112673662834`*^9}},ExpressionUUID->"5e9a4f1c-4f00-463d-a4d3-\
ad2fc88214d0"],

Cell[TextData[{
 StyleBox["----------------------------------14 day delay, \[Beta]=0.41 (",
  FontSize->16,
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontSize->16,
  FontWeight->"Bold",ExpressionUUID->"7b3da120-f234-4ee8-a952-a3927848e6f4"],
 StyleBox["=2.2)---------------------------------------------",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.8185219745172005`*^9, 3.8185220063364973`*^9}, {
  3.8189498295408616`*^9, 
  3.81894983066092*^9}},ExpressionUUID->"cfdd9687-c094-4a66-9327-\
d41e83812d81"],

Cell[TextData[{
 "Repeat these calculations for a 14 day delay vaccine, changing  the \[Beta] \
value, now to correspond to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],ExpressionUUID->
  "56f89757-f56f-4699-896c-a15c9eb0356e"],
 "=2.2.  ",
 StyleBox["Copy the command for \[OpenCurlyDoubleQuote]solstart\
\[CloseCurlyDoubleQuote], renaming it solstartR22 and changing the \[Beta] \
value accordingly.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.818348655250902*^9, 3.818348660873914*^9}, {
   3.818500626113576*^9, 3.81850062716148*^9}, 3.8189472332291555`*^9, {
   3.8189481754107914`*^9, 
   3.8189482336536665`*^9}},ExpressionUUID->"8eab12f1-1116-4486-b251-\
1eddd4f9ce52"],

Cell[TextData[{
 "\n",
 StyleBox["Next copy the command for \
``sample2delay14\[CloseCurlyDoubleQuote], renaming it, changing the \[Beta] \
value, and using solstartR22 for each initial history function.",
  FontColor->RGBColor[1, 0, 0]],
 "\n"
}], "Text",
 CellChangeTimes->{{3.8189482790783014`*^9, 
  3.818948308437538*^9}},ExpressionUUID->"fe7a8447-2743-4779-8b15-\
a45e4a004f9c"],

Cell[TextData[StyleBox["Give the requested graphs, determine the total number \
of deaths, total infections, and peak hospitalization and ICU usage.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{
  3.818948328621071*^9, {3.8199112720173235`*^9, 
   3.819911275033984*^9}},ExpressionUUID->"c409ced7-ebef-4a03-9028-\
a6a364cfcf97"],

Cell[TextData[{
 StyleBox["----------------------------------30 day delay, \[Beta]=0.28 (",
  FontSize->16,
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontSize->16,
  FontWeight->"Bold",ExpressionUUID->"f702aeb0-1a62-446f-81dd-bfb613ff6908"],
 StyleBox["=1.5)----------------------------------------------",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.8185220523614426`*^9, 3.8185220615270505`*^9}, {
  3.818949834381118*^9, 
  3.818949835413316*^9}},ExpressionUUID->"c8c9fd6b-79a4-4e25-8106-\
2921125acc71"],

Cell[TextData[{
 "Repeat these calculations for a 30 day delay vaccine, with \[Beta]=.28 \
value to correspond to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],ExpressionUUID->
  "2b4808a7-93e2-47a7-957c-9163bb1ffcfa"],
 "=1.5.  ",
 StyleBox["Copy the command for \[OpenCurlyDoubleQuote]solstart30\
\[CloseCurlyDoubleQuote], renaming it solstart30R15 and changing the \[Beta] \
value accordingly.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.8185016257300205`*^9, 3.8185017131290183`*^9}, {
  3.8189484670498505`*^9, 
  3.818948560510025*^9}},ExpressionUUID->"b3986b66-149f-429e-9eb2-\
4842aae76d69"],

Cell[TextData[{
 "\n",
 StyleBox["Next copy the command for \
``sample2delay30\[CloseCurlyDoubleQuote], renaming it sample2delay30R15, \
changing the \[Beta] value, and using solstart30R15 for each initial history \
function.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.818948588526024*^9, 
  3.8189486484929895`*^9}},ExpressionUUID->"cf01f522-7898-48bc-9b19-\
8c2f0445ebcc"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.818512665456467*^9, 
  3.818512691641014*^9}},ExpressionUUID->"49a43af2-beab-4e05-8b15-\
3d06dfc98e7b"],

Cell[TextData[StyleBox["Give the requested graphs, determine the total number \
of deaths, total infections, and peak hospitalization and ICU usage.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{
  3.8189487111090107`*^9, {3.8199112814380274`*^9, 
   3.819911289469353*^9}},ExpressionUUID->"4244eaa4-cce4-42e8-9f41-\
1569121e62c2"],

Cell[TextData[{
 StyleBox["----------------------------------30 day delay, \[Beta]=0.41 (",
  FontSize->16,
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],
  FontSize->16,
  FontWeight->"Bold",ExpressionUUID->"e289a5f3-1403-4469-82ce-2fc678482598"],
 StyleBox["=2.2)-------------------------------------------",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.818522078137147*^9, 3.818522094615648*^9}, {
  3.818949838526693*^9, 
  3.8189498442929163`*^9}},ExpressionUUID->"87dd2a29-c823-4c6b-a294-\
e2c415e5b609"],

Cell[TextData[{
 "Finally, repeat these calculations for a 30 day delay vaccine, this time \
with \[Beta] chosen to correspond to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],ExpressionUUID->
  "3a9c1d05-25d9-4716-9dbd-cfa9c9d6d95b"],
 "=2.2.  ",
 StyleBox["Copy the command for \[OpenCurlyDoubleQuote]solstart30\
\[CloseCurlyDoubleQuote], renaming it solstart30R22 and changing the \[Beta] \
value accordingly.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.8185127060800076`*^9, 3.818512751249539*^9}, {
  3.818521823671868*^9, 3.8185218241599045`*^9}, {3.8189487340857635`*^9, 
  3.818948786085893*^9}},ExpressionUUID->"f6f45e9b-f03e-484b-a403-\
422ca0c5e622"],

Cell[TextData[StyleBox["Next copy the command for ``sample2delay30\
\[CloseCurlyDoubleQuote], renaming it sample2delay30R22, changing the \[Beta] \
value, and using solstart30R22 for each initial history function.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.818948811766864*^9, 
  3.8189488315415525`*^9}},ExpressionUUID->"63327253-c1ff-4254-8d91-\
210e9651d9de"],

Cell[TextData[StyleBox["Give the requested graphs, determine the total number \
of deaths, total infections, and peak hospitalization and ICU usage.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{
  3.8189488743090053`*^9, {3.8199112962841873`*^9, 
   3.8199112990014143`*^9}},ExpressionUUID->"fb2098ec-2369-4ffc-ba52-\
96a27c78d280"],

Cell[TextData[StyleBox["------------------------------------------Faster pace \
of vaccination---------------------------------------",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.8185221289271297`*^9, 
  3.818522143479143*^9}},ExpressionUUID->"3028bfe7-343f-46f2-aaa4-\
f5d6882a2973"],

Cell[TextData[{
 "For the last question in part (k), we return to the 14 day delay vaccine, \
and \[Beta] for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "0"], TraditionalForm]],ExpressionUUID->
  "c21542fe-bb84-45e4-b699-c372ebcc279d"],
 "=1.8, but we increase \[Nu] to 0.01.  The original \
\[OpenCurlyDoubleQuote]solstart\[CloseCurlyDoubleQuote] applies to provide \
the initial history functions, and the only change we make to \
\[OpenCurlyDoubleQuote]sample2delay14\[CloseCurlyDoubleQuote] is to increase \
the rate of vaccination to 0.01.  ",
 StyleBox["Rename it \[OpenCurlyDoubleQuote]sample2delay14faster\
\[CloseCurlyDoubleQuote] and execute",
  FontColor->RGBColor[1, 0, 0]],
 "."
}], "Text",
 CellChangeTimes->{{3.8183488264658875`*^9, 3.818348900577884*^9}, {
  3.8185007960432014`*^9, 3.818500926257642*^9}, {3.8189489241489973`*^9, 
  3.8189489247890005`*^9}, {3.818948964789997*^9, 
  3.8189490508959837`*^9}},ExpressionUUID->"55f51507-7a01-4019-87e9-\
70d1f003202a"],

Cell[TextData[StyleBox["Determine total deaths, total infections, and peak \
hospitalization, summarizing the results in Table 4.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.818949117406091*^9, 
  3.8189491463739977`*^9}},ExpressionUUID->"bce54d75-ce5c-4f08-be5c-\
a8555d1e962f"],

Cell[TextData[StyleBox["-------------------------------------Comparing Option \
A and Option B-----------------------------------",
 FontSize->16,
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.818522166242154*^9, 3.818522180455456*^9}, {
  3.8189498469569163`*^9, 
  3.8189498481489124`*^9}},ExpressionUUID->"e0bc4046-1a43-4af4-be60-\
c39bc2753d86"],

Cell[TextData[{
 "For part (m), the only new calculations to do are those for Option B.  ",
 StyleBox["Compute the new progression, recovery, and mortality rates, and \
modify solstart30 (rename it solstartB) and sample2delay30 (rename it \
sample2delayOPTIONB) with these new values, then execute both commands in \
succession.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.8185133103119516`*^9, 3.818513370791944*^9}, {
  3.8185135398239346`*^9, 3.8185135620639334`*^9}, {3.8189494013085885`*^9, 
  3.818949450764941*^9}, {3.8194642144895115`*^9, 
  3.8194642262894993`*^9}},ExpressionUUID->"8bca384c-3111-4aec-968d-\
b991ce397daa"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.818424273946151*^9, 
  3.8184242928011703`*^9}},ExpressionUUID->"ca856236-78b2-440a-a9b3-\
e179a727d2a6"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8184243158651457`*^9, 3.8184243381620116`*^9}, {
   3.818424370443046*^9, 3.8184245402508817`*^9}, 
   3.818513526430132*^9},ExpressionUUID->"ea770b3f-7cd1-46bb-8154-\
3c070405faa0"],

Cell[TextData[StyleBox["Evaluate total deaths, total infections, and peak \
hospitalization for Option B and summarize your results in Table 6.",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.818949562396945*^9, 3.818949587100772*^9}, {
  3.8194642469373493`*^9, 3.8194642585134106`*^9}, {3.8199113799655447`*^9, 
  3.8199113804936614`*^9}},ExpressionUUID->"b3b0b1ad-2701-440d-8247-\
37814bb6b80f"]
},
WindowSize->{759, 833},
WindowMargins->{{Automatic, 44}, {3, Automatic}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792}},
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 202, 4, 34, "Text",ExpressionUUID->"a436f254-6b92-4a9e-b252-6eae1621cf32"],
Cell[763, 26, 1277, 24, 122, "Text",ExpressionUUID->"7a570a02-82fb-478f-a7ec-41eb3cabe267"],
Cell[2043, 52, 4467, 121, 162, "Input",ExpressionUUID->"529fa9d4-be55-48b6-ae77-78151d4ecad7"],
Cell[6513, 175, 437, 7, 34, "Text",ExpressionUUID->"ba05c20c-bd69-4c93-8303-4384f7a8d1c0"],
Cell[CellGroupData[{
Cell[6975, 186, 1270, 34, 86, "Input",ExpressionUUID->"fdeb75a8-38df-49a0-99cf-c277013b3c7d"],
Cell[8248, 222, 74001, 1339, 247, "Output",ExpressionUUID->"32accbf2-3184-4c31-8f9a-64b12e47cfd9"]
}, Open  ]],
Cell[82264, 1564, 656, 11, 100, "Text",ExpressionUUID->"d1d9170f-9c58-46f5-a743-fbda350651c8"],
Cell[CellGroupData[{
Cell[82945, 1579, 741, 18, 28, "Input",ExpressionUUID->"7966d57a-25d7-43cb-950d-152938f3f9ac"],
Cell[83689, 1599, 450, 10, 32, "Output",ExpressionUUID->"575c70b1-bd01-4388-b19e-d36b68576efd"]
}, Open  ]],
Cell[84154, 1612, 244, 6, 56, "Text",ExpressionUUID->"f1f11fa6-83c9-4dff-9c90-95fb29a668aa"],
Cell[CellGroupData[{
Cell[84423, 1622, 501, 12, 28, "Input",ExpressionUUID->"eee97169-0315-4011-a396-50bc17d6dc88"],
Cell[84927, 1636, 6704, 127, 232, "Output",ExpressionUUID->"c38944b5-eaff-421a-bc63-c25204536b5a"]
}, Open  ]],
Cell[91646, 1766, 648, 13, 100, "Text",ExpressionUUID->"7cf31a2d-d681-4916-909d-b8a142821fd2"],
Cell[CellGroupData[{
Cell[92319, 1783, 451, 11, 28, "Input",ExpressionUUID->"d581e644-2771-4696-a62e-69f714b57c95"],
Cell[92773, 1796, 308, 6, 32, "Output",ExpressionUUID->"042fe86e-7cdb-4113-9eff-6efe2a5df60e"]
}, Open  ]],
Cell[93096, 1805, 345, 7, 56, "Text",ExpressionUUID->"4fda1a0e-e9f5-4942-949c-e6b2cb675825"],
Cell[93444, 1814, 130, 3, 28, "Input",ExpressionUUID->"ac1252ee-df6d-4ca5-9f66-863ea46a7d7f"],
Cell[CellGroupData[{
Cell[93599, 1821, 395, 9, 28, "Input",ExpressionUUID->"3f1dff47-9f6a-4825-bf1f-3d2bcf2f5af6"],
Cell[93997, 1832, 307, 6, 32, "Output",ExpressionUUID->"d86060a1-64a9-42b2-b05f-9ab2054b3f33"]
}, Open  ]],
Cell[94319, 1841, 1180, 26, 166, "Text",ExpressionUUID->"35be1d6c-3f4f-4384-94ec-f06d13977884"],
Cell[95502, 1869, 214, 5, 35, "Text",ExpressionUUID->"b7c82171-4d57-4d99-9b0b-e73ae1c0e547"],
Cell[95719, 1876, 583, 18, 57, "Text",ExpressionUUID->"106baad3-f532-4d67-9e77-15906ce113a9"],
Cell[96305, 1896, 2272, 37, 320, "Text",ExpressionUUID->"a8faa265-4750-4e2b-99df-ed79574f1c85"],
Cell[98580, 1935, 9251, 245, 333, "Input",ExpressionUUID->"d071339b-bd38-4147-82a6-494f20e82a2e"],
Cell[107834, 2182, 411, 9, 78, "Text",ExpressionUUID->"67722a7d-f111-4d8f-a1ba-d263fdbe171a"],
Cell[108248, 2193, 10527, 286, 411, "Text",ExpressionUUID->"e50bc56f-1c01-4aa6-b951-f0aedbd4d16a"],
Cell[118778, 2481, 392, 6, 34, "Text",ExpressionUUID->"2d1c658d-67b9-4e93-b69e-52c6f056accd"],
Cell[CellGroupData[{
Cell[119195, 2491, 1729, 40, 86, "Input",ExpressionUUID->"3583c73d-06f8-4c91-9ac8-44167d12ed0d"],
Cell[120927, 2533, 60263, 1104, 247, "Output",ExpressionUUID->"7d522ea3-6562-4dec-b844-d7109e693cc1"]
}, Open  ]],
Cell[181205, 3640, 383, 9, 34, "Text",ExpressionUUID->"a8965629-1fdf-4124-bdfa-9cbd583bdf52"],
Cell[CellGroupData[{
Cell[181613, 3653, 811, 21, 48, "Input",ExpressionUUID->"78a2f32b-7a39-4c07-aca0-88f16e65ebe3"],
Cell[182427, 3676, 692, 13, 32, "Output",ExpressionUUID->"e55e35ba-58dc-4898-af25-546c8b76899a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183156, 3694, 594, 14, 28, "Input",ExpressionUUID->"5e65bd94-64b1-4772-847e-03ab414c35db"],
Cell[183753, 3710, 526, 9, 32, "Output",ExpressionUUID->"89407144-de79-43b6-9a04-5000a64edff6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184316, 3724, 460, 11, 28, "Input",ExpressionUUID->"270d8217-1c3a-406f-ad0c-4730a027b8a4"],
Cell[184779, 3737, 286, 6, 32, "Output",ExpressionUUID->"8b4a6bfe-2437-4f74-96b8-7f7c654a49eb"]
}, Open  ]],
Cell[185080, 3746, 662, 18, 35, "Text",ExpressionUUID->"fac5bd2d-f448-4c9c-9dd5-ae2274502279"],
Cell[185745, 3766, 665, 16, 56, "Text",ExpressionUUID->"008a876a-087b-4573-b127-96757eec3eb3"],
Cell[186413, 3784, 8985, 241, 333, "Input",ExpressionUUID->"1466ec87-a75a-4457-b40a-e1339e62a141"],
Cell[195401, 4027, 10814, 287, 485, "Input",ExpressionUUID->"fde58412-1f3a-4277-96f8-8e58c9f64951"],
Cell[CellGroupData[{
Cell[206240, 4318, 1280, 34, 86, "Input",ExpressionUUID->"555b1c8c-7a4c-4da2-9f3a-742316f43f20"],
Cell[207523, 4354, 62725, 1142, 241, "Output",ExpressionUUID->"0794e3ea-1328-4f17-a75b-6a6889e7c28d"]
}, Open  ]],
Cell[270263, 5499, 282, 5, 34, "Text",ExpressionUUID->"65ad7a27-d344-45e6-8b36-45a31e593b5b"],
Cell[CellGroupData[{
Cell[270570, 5508, 593, 18, 48, "Input",ExpressionUUID->"b0f35513-5b12-4bff-bc99-8f5f1f1c2493"],
Cell[271166, 5528, 328, 8, 32, "Output",ExpressionUUID->"bd4c3c8f-e1cc-491a-b1e2-c21ea9450bf9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[271531, 5541, 476, 12, 28, "Input",ExpressionUUID->"da652471-a9d5-46db-b077-5e4e0ac81fa3"],
Cell[272010, 5555, 282, 6, 32, "Output",ExpressionUUID->"7dcdc904-ee8b-4b99-bb6c-956996d31ea0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[272329, 5566, 458, 11, 28, "Input",ExpressionUUID->"7dd33404-e695-4809-bb67-51fcec68be6e"],
Cell[272790, 5579, 286, 6, 32, "Output",ExpressionUUID->"cb911aba-fda2-4e66-a703-b6db9b2e5733"]
}, Open  ]],
Cell[273091, 5588, 588, 16, 35, "Text",ExpressionUUID->"c122ecf9-e79d-4755-91d5-112723aa5357"],
Cell[273682, 5606, 1675, 39, 107, "Text",ExpressionUUID->"81259012-1f36-4e2f-9c1b-f7125f124fce"],
Cell[275360, 5647, 166, 3, 34, "Text",ExpressionUUID->"56feb663-be0b-410f-b1e6-8029b6ad4180"],
Cell[275529, 5652, 465, 7, 56, "Text",ExpressionUUID->"25db9940-f332-4900-9fcb-ca7b2f350080"],
Cell[275997, 5661, 383, 9, 78, "Text",ExpressionUUID->"5e9a4f1c-4f00-463d-a4d3-ad2fc88214d0"],
Cell[276383, 5672, 590, 16, 35, "Text",ExpressionUUID->"cfdd9687-c094-4a66-9327-d41e83812d81"],
Cell[276976, 5690, 730, 17, 56, "Text",ExpressionUUID->"8eab12f1-1116-4486-b251-1eddd4f9ce52"],
Cell[277709, 5709, 384, 10, 100, "Text",ExpressionUUID->"fe7a8447-2743-4779-8b15-a45e4a004f9c"],
Cell[278096, 5721, 345, 6, 56, "Text",ExpressionUUID->"c409ced7-ebef-4a03-9028-a6a364cfcf97"],
Cell[278444, 5729, 590, 16, 35, "Text",ExpressionUUID->"c8c9fd6b-79a4-4e25-8106-2921125acc71"],
Cell[279037, 5747, 651, 16, 56, "Text",ExpressionUUID->"b3986b66-149f-429e-9eb2-4842aae76d69"],
Cell[279691, 5765, 399, 10, 78, "Text",ExpressionUUID->"cf01f522-7898-48bc-9b19-8c2f0445ebcc"],
Cell[280093, 5777, 152, 3, 28, "Input",ExpressionUUID->"49a43af2-beab-4e05-8b15-3d06dfc98e7b"],
Cell[280248, 5782, 347, 6, 56, "Text",ExpressionUUID->"4244eaa4-cce4-42e8-9f41-1569121e62c2"],
Cell[280598, 5790, 585, 16, 35, "Text",ExpressionUUID->"87dd2a29-c823-4c6b-a294-e2c415e5b609"],
Cell[281186, 5808, 713, 16, 78, "Text",ExpressionUUID->"f6f45e9b-f03e-484b-a403-422ca0c5e622"],
Cell[281902, 5826, 384, 6, 56, "Text",ExpressionUUID->"63327253-c1ff-4254-8d91-210e9651d9de"],
Cell[282289, 5834, 349, 6, 56, "Text",ExpressionUUID->"fb2098ec-2369-4ffc-ba52-96a27c78d280"],
Cell[282641, 5842, 309, 6, 35, "Text",ExpressionUUID->"3028bfe7-343f-46f2-aaa4-f5d6882a2973"],
Cell[282953, 5850, 990, 21, 100, "Text",ExpressionUUID->"55f51507-7a01-4019-87e9-70d1f003202a"],
Cell[283946, 5873, 300, 5, 34, "Text",ExpressionUUID->"bce54d75-ce5c-4f08-be5c-a8555d1e962f"],
Cell[284249, 5880, 356, 7, 35, "Text",ExpressionUUID->"e0bc4046-1a43-4af4-be60-c39bc2753d86"],
Cell[284608, 5889, 656, 12, 78, "Text",ExpressionUUID->"8bca384c-3111-4aec-968d-b991ce397daa"],
Cell[285267, 5903, 154, 3, 28, "Input",ExpressionUUID->"ca856236-78b2-440a-a9b3-e179a727d2a6"],
Cell[285424, 5908, 231, 4, 28, "Input",ExpressionUUID->"ea770b3f-7cd1-46bb-8154-3c070405faa0"],
Cell[285658, 5914, 415, 6, 56, "Text",ExpressionUUID->"b3b0b1ad-2701-440d-8247-37814bb6b80f"]
}
]
*)

